﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci s ceníky kurzů
/// </summary>
public class CenikKurzu
{
    /// <summary>
    /// Ceník kurzu.
    /// </summary>
    /// <param name="idKurzu">Id kurzu.</param>
    public CenikKurzu(int idKurzu)
    {
        this.idKurzu = idKurzu;
        this.nazevKurzu = "";
        this.info = "";
        this.polozkyCeniku = new ArrayList();
    }

    /// <summary>
    /// Ceník kurzu.
    /// </summary>
    /// <param name="idKurzu">Id kurzu.</param>
    /// <param name="nazevKurzu">Název kurzu.</param>
    /// <param name="info">Info o kurzu.</param>
    public CenikKurzu(int idKurzu, string nazevKurzu, string info)
    {
        this.idKurzu = idKurzu;
        this.nazevKurzu = nazevKurzu;
        this.info = info;
        this.polozkyCeniku = new ArrayList();
    }

    private int idKurzu;

    /// <summary>
    /// Vrátí nebo nastaví id kurzu.
    /// </summary>
    public int IdKurzu
    {
        get { return this.idKurzu; }
        set { this.idKurzu = value; }
    }

    private string nazevKurzu;
    /// <summary>
    /// Vrátí nebo nastaví název kurzu.
    /// </summary>
    public string NazevKurzu
    {
        get { return this.nazevKurzu; }
        set { this.nazevKurzu = value; }
    }

    private string info;
    /// <summary>
    /// Vrátí nebo nastaví informace o kurzu.
    /// </summary>
    public string Info
    {
        get { return this.info; }
        set { this.info = value; }
    }

    private ArrayList polozkyCeniku;
    /// <summary>
    /// Vrátí nebo nastaví seznam položek ceníku.
    /// </summary>
    public ArrayList PolozkyCeniku
    {
        get { return polozkyCeniku; }
        set { polozkyCeniku = value; }
    }

    /// <summary>
    /// Vytvoří položku ceníku.
    /// </summary>
    /// <param name="cena">Cena za osobu.</param>
    /// <param name="doba">Počet dní (0 pro každý další den).</param>
    public void VytvorPolozkuCeniku(float cena, int doba)
    {
        PolozkaCeniku polozkaCeniku = new PolozkaCeniku(cena, doba);
        polozkyCeniku.Add(polozkaCeniku);
    }

    /// <summary>
    /// Vytvoří tabulku cen.
    /// </summary>
    /// <returns>HTML kód tabulky cen.</returns>
    public string VytvorTabulkuCen()
    {
        string tabulka = "<table>";
        string posledniRadek = "";
        foreach (PolozkaCeniku ceny in this.polozkyCeniku)
        {
            if (ceny.Doba == 0)
                posledniRadek = "<tr><td>Další den</td><td style=\"text-align: right;\">" + ceny.Cena.ToString("f2") + " Kč</td></tr>";
            else
                tabulka += "<tr><td>" + ceny.Doba + " " + FunkceRezervacnihoSystemu.GetStringPocetDni(ceny.Doba) + "</td><td style=\"text-align: right;\">" + ceny.Cena.ToString("f2") + " Kč</td></tr>";
        }
        return tabulka + posledniRadek + "</table>";
    }

    /// <summary>
    /// Načte ceník kurzu z databáze.
    /// </summary>
    /// <param name="polozky"><c>True</c>, pokud se mají načíst i položky ceníku, jinak <c>false</c>.</param>
    /// <returns><c>True</c>, pokud načtení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool NacistCenikKurzu(bool polozky)
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT nazev, info FROM kurz WHERE idKurzu='" + this.idKurzu + "';");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                this.nazevKurzu = reader["nazev"].ToString();
                this.info = reader["info"].ToString();
            }

            //Načtení položek ceníku
            if (polozky)
            {
                databaze.SetCommandText("SELECT cena, pocetDni FROM kurzCena WHERE idKurzu=" + this.idKurzu + " ORDER BY pocetDni;");
                reader = databaze.ExecuteReader();
                while (reader.Read())
                {
                    this.VytvorPolozkuCeniku(float.Parse(reader["cena"].ToString()), int.Parse(reader["pocetDni"].ToString()));
                }
            }
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Uloží ceník kurzu do databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool UlozitCenikKurzu()
    {
        try
        {
            Databaze databaze = new Databaze();
            SqlCommand cmd;

            if (this.idKurzu != 0)
                databaze.SetCommandText("UPDATE kurz SET nazev='" + this.nazevKurzu + "', info='" + this.info + "' WHERE idKurzu='" + this.idKurzu + "';");
            else
            {
                databaze.SetCommandText("SELECT MAX(idKurzu) AS max FROM kurz;");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                    if (int.TryParse(reader["max"].ToString(), out this.idKurzu))
                        this.idKurzu = int.Parse(reader["max"].ToString());
                this.idKurzu += 1;

                databaze.SetCommandText("INSERT INTO kurz (idKurzu, nazev, info) VALUES ('" + this.idKurzu + "', '" + this.nazevKurzu + "', '" + this.info + "');");
            }
            databaze.ExecuteReader();


            databaze.SetCommandText("DELETE FROM kurzCena WHERE idKurzu='" + this.idKurzu + "'");
            databaze.ExecuteReader();

            if (this.polozkyCeniku != null)
            {
                foreach (PolozkaCeniku polozka in this.polozkyCeniku)
                {
                    cmd = new SqlCommand("INSERT INTO kurzCena (idKurzu, pocetDni, cena) VALUES ('" + this.idKurzu + "', @pocetDni, @cena);");
                    SqlParameter parametr = new SqlParameter("@pocetDni", polozka.Doba);
                    cmd.Parameters.Add(parametr);
                    parametr = new SqlParameter("@cena", polozka.Cena);
                    cmd.Parameters.Add(parametr);
                    databaze.SetCommand(cmd);
                    databaze.ExecuteReader();
                }
            }

            return true;

        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Smaže ceník kurzu z databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool SmazatCenikKurzu()
    {
        try
        {
            Databaze databaze = new Databaze();

            // Smazání položek ceníku
            databaze.SetCommandText("DELETE FROM kurzCena WHERE idKurzu='" + this.idKurzu + "';");
            databaze.ExecuteReader();

            // Smazání kurzu
            databaze.SetCommandText("DELETE FROM kurz WHERE idKurzu='" + this.idKurzu + "';");
            databaze.ExecuteReader();

            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Vypočítá cenu kurzu za určitý počet dní.
    /// </summary>
    /// <param name="pocetDniKurzu">Počet dní kurzu.</param>
    /// <returns>Cena kurzu, v případě chyby -1.</returns>
    public float VypocitatCenuKurzu(int pocetDniKurzu)
    {
        if (this.polozkyCeniku.Count > 0)
        {
            //Zjistí se maximální počet dní
            int maxZadanyPocetDni = ((PolozkaCeniku)this.polozkyCeniku[this.polozkyCeniku.Count - 1]).Doba;
            //Pokud je počet dní kurzu větší než maximální počet dní v ceníku
            if (maxZadanyPocetDni < pocetDniKurzu)
                return ((PolozkaCeniku)this.polozkyCeniku[this.polozkyCeniku.Count - 1]).Cena + ((PolozkaCeniku)this.polozkyCeniku[0]).Cena * (pocetDniKurzu - maxZadanyPocetDni);

            //Začne se procházet seznam od počátku
            if (pocetDniKurzu < ((PolozkaCeniku)this.polozkyCeniku[this.polozkyCeniku.Count - 1]).Doba / 2)
                for (int i = 0; i < this.polozkyCeniku.Count; i++)
                {
                    if (((PolozkaCeniku)this.polozkyCeniku[i]).Doba == pocetDniKurzu)
                    {
                        return ((PolozkaCeniku)(this.polozkyCeniku[i])).Cena;
                    }
                }
            //Začne se procházet seznam od konce
            else
                for (int i = this.polozkyCeniku.Count - 1; i >= 0; i--)
                {
                    if (((PolozkaCeniku)this.polozkyCeniku[i]).Doba == pocetDniKurzu)
                    {
                        return ((PolozkaCeniku)(this.polozkyCeniku[i])).Cena;
                    }
                }
        }
        return -1;
    }

}
