﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections;
using System.Data.SqlClient;

/// <summary>
/// Summary description for CenikLyzarskehoVybaveni
/// </summary>
public class CenikLyzarskehoVybaveni
{
    private int idLyzarskehoVybaveni;
    private string nazevSetu;
    private string info;
    private ArrayList polozkyCeniku;
    private float pojistne;

    /// <summary>
    /// Ceník lyžařského vybavení.
    /// </summary>
    /// <param name="idLyzarskehoVybaveni">Id lyžařského vybavení.</param>
    /// <param name="nazevSetu">Název setu.</param>
    /// <param name="info">Informace.</param>
    /// <param name="pojistne">Pojistné.</param>
    public CenikLyzarskehoVybaveni(int idLyzarskehoVybaveni)
    {
        this.idLyzarskehoVybaveni = idLyzarskehoVybaveni;
        this.nazevSetu = "";
        this.info = "";
        this.pojistne = 0;
        this.polozkyCeniku = new ArrayList();
    }

    /// <summary>
    /// Ceník lyžařského vybavení.
    /// </summary>
    /// <param name="idLyzarskehoVybaveni">Id lyžařského vybavení.</param>
    /// <param name="nazevSetu">Název setu.</param>
    /// <param name="info">Informace.</param>
    /// <param name="pojistne">Pojistné.</param>
    public CenikLyzarskehoVybaveni(int idLyzarskehoVybaveni, string nazevSetu, string info, float pojistne)
    {
        this.idLyzarskehoVybaveni = idLyzarskehoVybaveni;
        this.nazevSetu = nazevSetu;
        this.info = info;
        this.pojistne = pojistne;
        this.polozkyCeniku = new ArrayList();
    }

    public int IdLyzarskehoVybaveni
    {
        get { return this.idLyzarskehoVybaveni; }
        set { this.idLyzarskehoVybaveni = value; }
    }

    public string NazevSetu
    {
        get { return this.nazevSetu; }
        set { this.nazevSetu = value; }
    }

    public string Info
    {
        get { return this.info; }
        set { this.info = value; }
    }

    public ArrayList PolozkyCeniku
    {
        get { return polozkyCeniku; }
        set { polozkyCeniku = value; }
    }

    public float Pojistne
    {
        get { return pojistne; }
        set { pojistne = value; }
    }

    public void VytvorPolozkuCeniku(float cena, int doba)
    {
        PolozkaCeniku polozkaCeniku = new PolozkaCeniku(cena, doba);
        polozkyCeniku.Add(polozkaCeniku);
    }


    /// <summary>
    /// Vytvoří tabulku cen
    /// </summary>
    /// <returns>HTML kód tabulky cen</returns>
    public Table VytvorTabulkuCen()
    {
        Table table = new Table();

        TableRow tr = new TableRow();
        TableCell td = new TableCell();
        td.Text = "Pojistné/den";
        tr.Cells.Add(td);

        td = new TableCell();
        td.Text = this.pojistne + " Kč";
        td.HorizontalAlign = HorizontalAlign.Right;
        tr.Cells.Add(td);
        table.Rows.Add(tr);

        string posledniRadek = "";
        foreach (PolozkaCeniku ceny in this.polozkyCeniku)
        {
            tr = new TableRow();

            td = new TableCell();

            if (ceny.Doba == 0)
                td.Text = "Další den";
            else
                td.Text = ceny.Doba + " " + FunkceRezervacnihoSystemu.GetStringPocetDni(ceny.Doba);
            tr.Cells.Add(td);

            td = new TableCell();
            td.Text = ceny.Cena.ToString("f2") + " Kč";
            td.HorizontalAlign = HorizontalAlign.Right;
            tr.Cells.Add(td);

            if (ceny.Doba == 0)
                table.Rows.AddAt(table.Rows.Count - 1, tr);
            else
                table.Rows.AddAt(table.Rows.Count - 2, tr);
        }
        return table;
    }

    /// <summary>
    /// Načte cenik lyžařského vybavení z databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud načtení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool NacistCenikLyzarskehoVybaveni()
    {
        try
        {
            Databaze databaze = new Databaze();

            databaze.SetCommandText("SELECT nazev, pojistne, info FROM lyzarskeVybaveni WHERE idVybaveni=" + this.idLyzarskehoVybaveni + ";");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                this.nazevSetu = reader["nazev"].ToString();
                this.pojistne = float.Parse(reader["pojistne"].ToString());
                this.info = reader["info"].ToString();
            }

            //Načte položky
            databaze.SetCommandText("SELECT cena, pocetDni FROM lyzarskeVybaveniCena WHERE idVybaveni=" + this.idLyzarskehoVybaveni + " ORDER BY pocetDni;");
            reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                this.VytvorPolozkuCeniku(float.Parse(reader["cena"].ToString()), int.Parse(reader["pocetDni"].ToString()));
            }
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }


    /// <summary>
    /// Vypočítá cenu vybavení za určitý počet dní.
    /// </summary>
    /// <param name="pocetDniKurzu">Počet dní půjčení vybavení.</param>
    /// <returns>Cena vybavení, v případě chyby -1.</returns>
    public float VypocitejCenuVybaveni(int pocetDni)
    {
        float cenaPojistka = this.pojistne * pocetDni;
        if (this.polozkyCeniku.Count > 0)
        {
            //Zjistí se maximální počet dní
            int maxZadanyPocetDni = ((PolozkaCeniku)this.polozkyCeniku[this.polozkyCeniku.Count - 1]).Doba;
            //Pokud je počet dní vypůjčení větší než maximální počet dní v ceníku
            if (maxZadanyPocetDni < pocetDni)
                return (((PolozkaCeniku)this.polozkyCeniku[this.polozkyCeniku.Count - 1]).Cena + ((PolozkaCeniku)this.polozkyCeniku[0]).Cena * (pocetDni - maxZadanyPocetDni) + cenaPojistka);

            //Začne se procházet seznam od počátku
            if (pocetDni < ((PolozkaCeniku)this.polozkyCeniku[this.polozkyCeniku.Count - 1]).Doba / 2)
                for (int i = 0; i < this.polozkyCeniku.Count; i++)
                {
                    if (((PolozkaCeniku)this.polozkyCeniku[i]).Doba == pocetDni)
                    {
                        return (((PolozkaCeniku)(this.polozkyCeniku[i])).Cena + cenaPojistka);
                    }
                }
            //Začne se procházet seznam od konce
            else
                for (int i = this.polozkyCeniku.Count - 1; i > 0; i--)
                {
                    if (((PolozkaCeniku)this.polozkyCeniku[i]).Doba == pocetDni)
                    {
                        return (((PolozkaCeniku)(this.polozkyCeniku[i])).Cena + cenaPojistka);
                    }
                }
        }
        return -1;
    }

    /// <summary>
    /// Smaže ceník vybavení z databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool SmazatCenikVybaveni()
    {
        try
        {
            Databaze databaze = new Databaze();

            // Smazání položek ceníku
            databaze.SetCommandText("DELETE FROM lyzarskeVybaveniCena WHERE idVybaveni='" + this.idLyzarskehoVybaveni + "';");
            databaze.ExecuteReader();

            // Smazání kurzu
            databaze.SetCommandText("DELETE FROM lyzarskeVybaveni WHERE idVybaveni='" + this.idLyzarskehoVybaveni + "';");
            databaze.ExecuteReader();

            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }


    /// <summary>
    /// Uloží ceník vybavení do databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool UlozitCenikVybaveni()
    {
        try
        {
            Databaze databaze = new Databaze();
            SqlCommand cmd;

            if (this.idLyzarskehoVybaveni != 0)
                cmd = new SqlCommand("UPDATE lyzarskeVybaveni SET nazev='" + this.nazevSetu + "', info='" + this.info + "', pojistne=@pojistne WHERE idVybaveni='" + this.idLyzarskehoVybaveni + "';");
            else
            {
                databaze.SetCommandText("SELECT MAX(idVybaveni) AS max FROM lyzarskeVybaveni;");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                    if (int.TryParse(reader["max"].ToString(), out this.idLyzarskehoVybaveni))
                        this.idLyzarskehoVybaveni = int.Parse(reader["max"].ToString());
                this.idLyzarskehoVybaveni += 1;

                cmd = new SqlCommand("INSERT INTO lyzarskeVybaveni (idVybaveni, nazev, info, pojistne) VALUES ('" + this.idLyzarskehoVybaveni + "', '" + this.nazevSetu+ "', '" + this.info + "', @pojistne);");
            }
            SqlParameter parametr = new SqlParameter("@pojistne", this.pojistne);
            cmd.Parameters.Add(parametr);
            databaze.SetCommand(cmd);
            databaze.ExecuteReader();


            databaze.SetCommandText("DELETE FROM lyzarskeVybaveniCena WHERE idVybaveni='" + this.idLyzarskehoVybaveni + "'");
            databaze.ExecuteReader();

            if (this.polozkyCeniku != null)
            {
                foreach (PolozkaCeniku polozka in this.polozkyCeniku)
                {
                    cmd = new SqlCommand("INSERT INTO lyzarskeVybaveniCena (idVybaveni, pocetDni, cena) VALUES ('" + this.idLyzarskehoVybaveni + "', @pocetDni, @cena);");
                    parametr = new SqlParameter("@pocetDni", polozka.Doba);
                    cmd.Parameters.Add(parametr);
                    parametr = new SqlParameter("@cena", polozka.Cena);
                    cmd.Parameters.Add(parametr);
                    databaze.SetCommand(cmd);
                    databaze.ExecuteReader();
                }
            }

            return true;

        }
        catch (Exception)
        {
            return false;
        }
    }
}
