﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci s cenami skibalíčků
/// </summary>
public class CenikSkibalicku
{
    int idSkibalicku;
    string nazevSkibalicku;
    CenikKurzu kurz;
    int pocetDniKurzu;
    int pocetDniVybaveni;
    float cena;

    /// <summary>
    /// Ceník skibalíčku.
    /// </summary>
    /// <param name="idSkibalicku">Id skibalíčku.</param>
    public CenikSkibalicku(int idSkibalicku)
    {
        this.idSkibalicku = idSkibalicku;
        this.nazevSkibalicku = "";
        this.kurz = null;
        this.pocetDniKurzu = 0;
        this.pocetDniVybaveni = 0;
        this.cena = 0;
    }

    /// <summary>
    /// Ceník skibalíčku.
    /// </summary>
    /// <param name="idSkibalicku">Id skibalíčku.</param>
    /// <param name="nazevSkibalicku">Název skibalíčku.</param>
    /// <param name="kurz">Kurz.</param>
    /// <param name="pocetDniKurzu">Počet dní kurzu.</param>
    /// <param name="pocetDniVybaveni">Počet dní vybavení.</param>
    /// <param name="cena">Cena.</param>
    public CenikSkibalicku(int idSkibalicku, string nazevSkibalicku, CenikKurzu kurz, int pocetDniKurzu, int pocetDniVybaveni, float cena)
    {
        this.idSkibalicku = idSkibalicku;
        this.nazevSkibalicku = nazevSkibalicku;
        this.kurz = kurz;
        this.pocetDniKurzu = pocetDniKurzu;
        this.pocetDniVybaveni = pocetDniVybaveni;
        this.cena = cena;
    }

    /// <summary>
    /// Vrátí nebo nastaví id skibalíčku.
    /// </summary>
    public int IdSkibalicku
    {
        get { return idSkibalicku; }
        set { idSkibalicku = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví název skibalíčku.
    /// </summary>
    public string NazevSkibalicku
    {
        get { return nazevSkibalicku; }
        set { nazevSkibalicku = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví kurz skibalíčku.
    /// </summary>
    public CenikKurzu Kurz
    {
        get { return kurz; }
        set { kurz = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví počet dní kurzu.
    /// </summary>
    public int PocetDniKurzu
    {
        get { return pocetDniKurzu; }
        set { pocetDniKurzu = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví počet dní zapůjčení vybavení.
    /// </summary>
    public int PocetDniVybaveni
    {
        get { return pocetDniVybaveni; }
        set { pocetDniVybaveni = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví cenu.
    /// </summary>
    public float Cena
    {
        get { return cena; }
        set { cena = value; }
    }

    /// <summary>
    /// Načte skibalíček z databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud načtení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool NacistSkibalicek()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT nazevSkiBalicku, idKurzu, pocetDniKurzu, pocetDniVybaveni, cena FROM skibalicek WHERE idSkiBalicku='" + this.idSkibalicku + "';");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                this.nazevSkibalicku = reader["nazevSkiBalicku"].ToString();
                this.kurz = SpravceCeniku.NacistCenikKurzu(int.Parse(reader["idKurzu"].ToString()), false);
                this.pocetDniKurzu = int.Parse(reader["pocetDniKurzu"].ToString());
                this.pocetDniVybaveni = int.Parse(reader["pocetDniVybaveni"].ToString());
                this.cena = float.Parse(reader["cena"].ToString());
            }
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Uloží skibalíček do databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool UlozitSkibalicek()
    {
        try
        {
            Databaze databaze = new Databaze();
            SqlCommand cmd;
            if (this.idSkibalicku != 0)
            {
                //Update
                cmd = new SqlCommand("UPDATE skibalicek SET nazevSkiBalicku='" + this.nazevSkibalicku + "', idKurzu='" + this.kurz.IdKurzu + "', pocetDniKurzu='" + this.pocetDniKurzu + "', pocetDniVybaveni='" + this.pocetDniVybaveni + "', cena=@cena WHERE idSkiBalicku='" + this.idSkibalicku + "';");
            }
            else
            {
                databaze.SetCommandText("SELECT MAX(idSkiBalicku) AS max FROM skibalicek");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                    if (int.TryParse(reader["max"].ToString(), out this.idSkibalicku))
                        this.idSkibalicku = int.Parse(reader["max"].ToString());
                this.idSkibalicku += 1;

                //Insert
                cmd = new SqlCommand("INSERT INTO skibalicek (idSkiBalicku, nazevSkiBalicku, idKurzu, pocetDniKurzu, pocetDniVybaveni, cena) VALUES " +
                        "(" + this.idSkibalicku + ", '" + this.nazevSkibalicku + "', '" + this.kurz.IdKurzu + "', '" + this.pocetDniKurzu + "', " + this.pocetDniVybaveni + ", @cena);");
            }
            SqlParameter parametr = new SqlParameter("@cena", this.cena);
            cmd.Parameters.Add(parametr);

            databaze.SetCommand(cmd);
            databaze.ExecuteReader();

            return true;
        }
        catch (Exception ex)
        {
            return false; ;
        }
    }

    /// <summary>
    /// Smaže skibalíček z databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool SmazatSkibalicek()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("DELETE FROM skibalicek WHERE idSkiBalicku='" + this.idSkibalicku + "';");
            databaze.ExecuteReader();
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }
}
