﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci s partnerem lyžařské školy.
/// </summary>
public class Partner : Uzivatel
{
    private string partnerskyKod;
    private string firma;

    /// <summary>
    /// Partner lyžařské školy.
    /// </summary>
    /// <param name="idPartnera">Id partnera.</param>
    public Partner(string idPartnera)
        : base(idPartnera)
    {
        this.partnerskyKod = "";
        this.firma = "";
    }

    /// <summary>
    /// Partner lyžařské školy.
    /// </summary>
    /// <param name="idPartnera">Id partnera.</param>
    /// <param name="nick">Uživatelské jméno.</param>    
    /// <param name="jmeno">Jméno.</param>
    /// <param name="prijmeni">Přijmení.</param>
    /// <param name="email">Email.</param>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <param name="telefonniCislo">Telefonní číslo.</param>
    /// <param name="firma">Název firmy partnera.</param>
    public Partner(string idPartnera, string nick, string jmeno, string prijmeni, string email, string partnerskyKod, string telefonniCislo, string firma)
        : base(idPartnera, nick, "", jmeno, prijmeni, email, telefonniCislo)
    {
        this.partnerskyKod = partnerskyKod;
        this.firma = firma;
    }

    /// <summary>
    /// Vrátí nebo nastaví partnerský kód.
    /// </summary>
    public string PartnerskyKod
    {
        get { return partnerskyKod; }
        set { this.partnerskyKod = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví název firmy.
    /// </summary>
    public string Firma
    {
        get { return firma; }
        set { firma = value; }
    }

    /// <summary>
    /// Načte partnera z databáze.
    /// </summary>
    /// <returns><c>True</c> v případě, že načtení proběhlo úspěšně, jinak <c>false</c>.</returns>
    public bool Nacist()
    {
        if (base.Nacist())
        {
            try
            {
                Databaze databaze = new Databaze();
                databaze.SetCommandText("SELECT firma, partnerskyKod FROM partner WHERE idUzivatele='" + this.Id + "';");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                {
                    this.firma = reader["firma"].ToString();
                    this.partnerskyKod = reader["partnerskyKod"].ToString();
                    return true;
                }
            }
            catch (Exception)
            {
                return false;
            }
        }
        return false;
    }

    /// <summary>
    /// Uloží partnera do databáze.
    /// </summary>
    /// <returns><c>True</c> v případě, že uložení proběhlo úspěšně, jinak <c>false</c>.</returns>
    public bool Ulozit()
    {
        try
        {
            if (base.Ulozit())
            {
                Databaze databaze = new Databaze();

                bool exist = false;
                databaze.SetCommandText("SELECT 'r' FROM partner WHERE idUzivatele='" + this.Id + "'");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                    exist = true;

                if (exist)
                    databaze.SetCommandText("UPDATE partner SET firma='" + this.firma + "' WHERE idUzivatele='" + this.Id + "';");
                else
                {
                    databaze.SetCommandText("SELECT partnerskyKod FROM partner;");
                    reader = databaze.ExecuteReader();
                    ArrayList seznamKodu = new ArrayList();
                    while (reader.Read())
                    {
                        seznamKodu.Add(reader["partnerskyKod"].ToString());
                    }
                    Random random = new Random();
                    string novyKod;
                    do
                    {
                        novyKod = "";
                        for (int i = 0; i < 10; i++)
                        {
                            novyKod += random.Next(9).ToString();
                        }
                    } while (seznamKodu.Contains(novyKod));

                    databaze.SetCommandText("INSERT INTO partner (idUzivatele, firma, partnerskyKod) VALUES ('" + this.Id + "','" + this.firma + "', '" + novyKod + "');");
                }
                databaze.ExecuteReader();
                return true;
            }
            else
                return false;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Zjistí, zda existuje partnerský kód.
    /// </summary>
    /// <param name="partnerskyKod">Partnerský kód, u kterého se má zjistit existence.</param>
    /// <returns><c>True</c> pokud existuje, jinak <c>false</c>.</returns>
    public static bool ExistujePartnerskyKod(string partnerskyKod)
    {
        Databaze databaze = new Databaze();
        databaze.SetCommandText("SELECT 'r' FROM partner WHERE partnerskyKod='" + partnerskyKod + "';");
        SqlDataReader reader = databaze.ExecuteReader();
        while (reader.Read())
        {
            return true;
        }
        return false;
    }

    /// <summary>
    /// Načte id partnera podle partnerského kódu.
    /// </summary>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <returns>Id partnerského kódu, pokud neexistuje, tak <c>null</c>.</returns>
    public static string NacistIdPartneraPodlePartnerskehoKodu(string partnerskyKod)
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT idUzivatele FROM partner WHERE partnerskyKod='" + partnerskyKod + "';");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                return reader["idUzivatele"].ToString();
            }
        }
        catch (Exception)
        {
        }
        return "";
    }

    /// <summary>
    /// Smaže partnera z databáze.
    /// </summary>
    /// <returns><c>True</c> v případě, že smazání proběhlo úspěšně, jinak <c>False</c>.</returns>
    public bool Smazat()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("DELETE FROM partner WHERE idUzivatele='" + this.Id + "';");
            databaze.ExecuteReader();

            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

}
