﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Data.SqlClient;
using System.Data.SqlTypes;

/// <summary>
/// Třída pro práci s provizemi.
/// </summary>
public class Provize
{
    private Rezervace rezervace;
    private float vyseProvize;
    private DateTime datumVyplaceni;
    private string poznamka;
    private Partner partner;

    /// <summary>
    /// Provize.
    /// </summary>
    /// <param name="vyseProvize">Výše provize.</param>
    /// <param name="partner">Partner.</param>
    public Provize(Rezervace rezervace)
    {
        this.rezervace = rezervace;
    }

    /// <summary>
    /// Provize.
    /// </summary>
    /// <param name="vyseProvize">Výše provize.</param>
    /// <param name="partner">Partner.</param>
    public Provize(float vyseProvize, Partner partner)
    {
        this.vyseProvize = vyseProvize;
        this.partner = partner;
        this.poznamka = "";
    }

    /// <summary>
    /// Provize.
    /// </summary>
    /// <param name="vyseProvize">Výše provize.</param>
    /// <param name="datumVyplaceni">Datum vyplacení.</param>
    /// <param name="poznamka">Poznámka.</param>
    /// <param name="partner">Partner.</param>
    /// <param name="rezervace">Rezervace.</param>
    public Provize(float vyseProvize, DateTime datumVyplaceni, string poznamka, Partner partner, Rezervace rezervace)
    {
        this.vyseProvize = vyseProvize;
        this.partner = partner;
        this.poznamka = poznamka;
        this.datumVyplaceni = datumVyplaceni;
        this.rezervace = rezervace;
    }

    /// <summary>
    /// Vrátí nebo nastaví rezervaci.
    /// </summary>
    public Rezervace Rezervace
    {
        get { return rezervace; }
        set { rezervace = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví výši provize.
    /// </summary>
    public float VyseProvize
    {
        get { return vyseProvize; }
        set { vyseProvize = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví datum vyplacení.
    /// </summary>
    public DateTime DatumVyplaceni
    {
        get { return datumVyplaceni; }
        set { datumVyplaceni = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví poznámku
    /// </summary>
    public string Poznamka
    {
        get { return poznamka; }
        set { poznamka = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví partnera.
    /// </summary>
    public Partner Partner
    {
        get { return partner; }
        set { partner = value; }
    }


    /// <summary>
    /// Načte provizi
    /// </summary>
    /// <returns></returns>
    public bool Nacist()
    {
        try
        {
            if (this.rezervace.ReferencniCislo == 0)
                return false;
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT idPartnera, provize, datumVyplaceni, poznamka FROM rezervaceProvize WHERE idRezervace='" + this.rezervace.ReferencniCislo + "';");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                if (DateTime.TryParse(reader["datumVyplaceni"].ToString(), out this.datumVyplaceni))
                    this.datumVyplaceni = DateTime.Parse(reader["datumVyplaceni"].ToString());
                this.partner = new Partner(reader["idPartnera"].ToString());
                this.poznamka = reader["poznamka"].ToString();
                if (float.TryParse(reader["provize"].ToString(), out this.vyseProvize))
                    this.vyseProvize = float.Parse(reader["provize"].ToString());
            }
            if (this.partner.Jmeno == null)
                if (!this.partner.Nacist())
                    return false;
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }


    public bool Ulozit()
    {
        try
        {
            Databaze databaze = new Databaze();
            SqlCommand cmd;

            cmd = new SqlCommand("UPDATE rezervaceProvize SET provize=@provize, datumVyplaceni=@datum, poznamka='" + this.poznamka + "' WHERE idRezervace='" + this.rezervace.ReferencniCislo + "'");
            SqlParameter parametr = new SqlParameter("@provize", this.vyseProvize);
            cmd.Parameters.Add(parametr);
            if (this.datumVyplaceni == DateTime.MinValue)
                parametr = new SqlParameter("@datum", SqlDateTime.Null);
            else
                parametr = new SqlParameter("@datum", this.datumVyplaceni);
            cmd.Parameters.Add(parametr);
            databaze.SetCommand(cmd);
            databaze.ExecuteReader();

            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

}
