﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci s rezervacemi
/// </summary>
public class Rezervace
{
    protected int referencniCislo;
    protected Zakaznik zakaznik;
    protected Pobocka pobocka;
    protected string partnerskyKod;
    protected float cenaPredSlevou;
    protected Slevy slevy;
    protected float cenaKonecna;
    protected RezervaceStav stavRezervace;
    protected DateTime zacatekRezervace;
    protected DateTime konecRezervace;
    protected string jineSdeleni;
    protected string poznamka;


    /// <summary>
    /// Rezervace
    /// </summary>
    /// <param name="referencniCislo">Referenční číslo</param>
    /// <param name="zakaznik">Zákazník</param>
    public Rezervace(int referencniCislo, Zakaznik zakaznik)
    {
        this.referencniCislo = referencniCislo;
        this.zakaznik = zakaznik;
    }

    /// <summary>
    /// Rezervace.
    /// </summary>
    /// <param name="referencniCislo">Referenční číslo (id rezervace).</param>
    /// <param name="zakaznik">Zákazník.</param>
    /// <param name="pobocka">Pobočka.</param>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <param name="cenaPredSlevou">Cena před slevou.</param>
    /// <param name="slevy">Slevy.</param>
    /// <param name="cenaKonecna">Cena konečná.</param>
    /// <param name="zacatekRezervace">Datum začátku rezervace.</param>
    /// <param name="konecRezervace">Datum konce rezervace.</param>
    /// <param name="stavRezervace">Stav rezervace.</param>
    /// <param name="jineSdeleni">Jiné sdělení.</param>
    public Rezervace(int referencniCislo, Zakaznik zakaznik,
        Pobocka pobocka, string partnerskyKod,
        float cenaPredSlevou, Slevy slevy, float cenaKonecna,
        DateTime zacatekRezervace, DateTime konecRezervace, RezervaceStav stavRezervace, string jineSdeleni)
    {
        this.referencniCislo = referencniCislo;
        this.zakaznik = zakaznik;
        this.pobocka = pobocka;
        this.partnerskyKod = partnerskyKod;
        this.cenaPredSlevou = cenaPredSlevou;
        this.slevy = slevy;
        this.cenaKonecna = cenaKonecna;
        this.zacatekRezervace = zacatekRezervace;
        this.konecRezervace = konecRezervace;
        this.stavRezervace = stavRezervace;
        this.jineSdeleni = jineSdeleni;
    }

    /// <summary>
    /// Rezervace.
    /// </summary>
    /// <param name="zakaznik">Zákazník.</param>
    /// <param name="pobocka">Pobočka.</param>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <param name="cenaPredSlevou">Cena před slevou.</param>
    /// <param name="slevy">Slevy.</param>
    /// <param name="cenaKonecna">Cena konečná.</param>
    /// <param name="zacatekRezervace">Datum začátku rezervace.</param>
    /// <param name="konecRezervace">Datum konce rezervace.</param>
    /// <param name="jineSdeleni">Jiné sdělení.</param>
    public Rezervace(Zakaznik zakaznik,
        Pobocka pobocka, string partnerskyKod,
        float cenaPredSlevou, Slevy slevy, float cenaKonecna,
        DateTime zacatekRezervace, DateTime konecRezervace, string jineSdeleni)
    {
        this.referencniCislo = 0;
        this.zakaznik = zakaznik;
        this.pobocka = pobocka;
        this.partnerskyKod = partnerskyKod;
        this.cenaPredSlevou = cenaPredSlevou;
        this.slevy = slevy;
        this.cenaKonecna = cenaKonecna;
        this.zacatekRezervace = zacatekRezervace;
        this.konecRezervace = konecRezervace;
        this.jineSdeleni = jineSdeleni;
    }

    /// <summary>
    /// Vrátí nebo nastaví referenční číslo (id rezervace)
    /// </summary>
    public int ReferencniCislo
    {
        get { return referencniCislo; }
        set { referencniCislo = value; }
    }


    /// <summary>
    /// Uloží rezervaci do databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool UlozitRezervaci()
    {
        try
        {
            Databaze databaze = new Databaze();
            SqlCommand cmd;
            if (this.referencniCislo != 0)
            {
                cmd = new SqlCommand("UPDATE rezervace SET idZakaznika='" + zakaznik.Id + "', od='" + this.zacatekRezervace.ToString("yyyy-MM-dd") + "', do='" + this.konecRezervace.ToString("yyyy-MM-dd") + "', " +
                    "pobocka='" + this.pobocka.IdPobocky + "', partnerskyKod='" + this.partnerskyKod + "', cenaPredSlevou=@cenaPredSlevou, slevaOnline=@slevaOnline, slevaTermin=@slevaTermin, slevaPocet=@slevaPocet, slevaPartnerskyKod=@slevaPartnerskyKod, slevaCelkem=@slevaCelkem, cenaKonecna=@cenaKonecna, idStavuRezervace='" + stavRezervace.IdStavuRezervace + "', poznamka='" + this.jineSdeleni + "', poznamkaAdmina='" + this.poznamka + "' " +
                    "WHERE idRezervace='" + this.referencniCislo + "';");
            }
            else
            {
                databaze.SetCommandText("SELECT MAX(idRezervace) AS max FROM rezervace");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                    if (int.TryParse(reader["max"].ToString(), out this.referencniCislo))
                        this.referencniCislo = int.Parse(reader["max"].ToString());
                this.referencniCislo += 1;

                if (partnerskyKod != "")
                {
                    string idParntera = SpravceUzivatelu.NacistIdPartneraPodlePartnerskehoKodu(partnerskyKod);
                    databaze.SetCommandText("INSERT INTO rezervaceProvize (idRezervace, idPartnera) VALUES ('" + this.referencniCislo + "','" + idParntera + "');");
                    databaze.ExecuteReader();
                }

                cmd = new SqlCommand("INSERT INTO rezervace (idRezervace, idZakaznika, od, do, pobocka, partnerskyKod, cenaPredSlevou, slevaOnline, slevaTermin, slevaPocet, slevaPartnerskyKod, slevaCelkem, cenaKonecna, idStavuRezervace, poznamka, poznamkaAdmina) VALUES " +
                        "(" + this.referencniCislo + ", '" + zakaznik.Id + "', '" + zacatekRezervace.ToString("yyyy-MM-dd") + "', '" + konecRezervace.ToString("yyyy-MM-dd") + "', " + pobocka.IdPobocky + ", '" + partnerskyKod + "', @cenaPredSlevou, @slevaOnline, @slevaTermin, @slevaPocet, @slevaPartnerskyKod, @slevaCelkem , @cenaKonecna, '-1', '" + this.jineSdeleni + "', '" + this.poznamka + "');");
            }
            SqlParameter parametr = new SqlParameter("@cenaPredSlevou", cenaPredSlevou);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@cenaKonecna", cenaKonecna);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@slevaOnline", slevy.OnLineRezervace);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@slevaTermin", slevy.VcasnaRezervace);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@slevaPocet", slevy.SlevaPocetOsob);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@slevaPartnerskyKod", slevy.PouzitiPartnerskehoKodu);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@slevaCelkem", slevy.MaximalniSleva);
            cmd.Parameters.Add(parametr);

            databaze.SetCommand(cmd);
            databaze.ExecuteReader();

            return true;
        }
        catch (Exception ex)
        {
            return false; ;
        }
    }

    /// <summary>
    /// Smaže rezervaci z databáze.
    /// </summary>
    public bool SmazatRezervaci()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("DELETE FROM rezervace WHERE idrezervace=" + this.referencniCislo + ";");
            databaze.ExecuteReader();
            databaze.SetCommandText("DELETE FROM rezervaceProvize WHERE idrezervace=" + this.referencniCislo + ";");
            databaze.ExecuteReader();
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Načte rezervaci
    /// </summary>
    public bool NacistRezervaci()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT od, do, pobocka, idZakaznika, nazevPobocky, partnerskyKod, cenaPredSlevou, slevaOnline, slevaTermin, slevaPocet, slevaPartnerskyKod, slevaCelkem, cenaKonecna, stavRezervace, poznamka, poznamkaAdmina, idStavuRezervace FROM rezervaceView WHERE idRezervace='" + this.referencniCislo + "';");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                this.pobocka = new Pobocka(int.Parse(reader["pobocka"].ToString()), reader["nazevPobocky"].ToString());
                this.partnerskyKod = reader["partnerskyKod"].ToString();
                this.cenaPredSlevou = float.Parse(reader["cenaPredSlevou"].ToString());
                this.slevy = new Slevy(float.Parse(reader["slevaCelkem"].ToString()), float.Parse(reader["slevaOnline"].ToString()), float.Parse(reader["slevaPartnerskyKod"].ToString()), float.Parse(reader["slevaTermin"].ToString()), float.Parse(reader["slevaPocet"].ToString()));
                this.cenaKonecna = float.Parse(reader["cenaKonecna"].ToString());
                this.zacatekRezervace = DateTime.Parse(reader["od"].ToString());
                this.konecRezervace = DateTime.Parse(reader["do"].ToString());
                this.stavRezervace = new RezervaceStav(reader["stavRezervace"].ToString());
                this.jineSdeleni = reader["poznamka"].ToString();
                this.poznamka = reader["poznamkaAdmina"].ToString();
                this.stavRezervace.IdStavuRezervace = int.Parse(reader["idStavuRezervace"].ToString());
                this.stavRezervace.NacistStavRezervace();
                if (this.zakaznik == null)
                    this.zakaznik = SpravceUzivatelu.NacistZakaznika(reader["idZakaznika"].ToString());
                if(this.zakaznik==null)
                    this.zakaznik = new Zakaznik(reader["idZakaznika"].ToString());
                return true;
            }

            return false;
        }
        catch (Exception ex)
        {
            return false;
        }
    }







    public Zakaznik Zakaznik { get { return zakaznik; } set { zakaznik = value; } }
    public Pobocka Pobocka { get { return pobocka; } set { pobocka = value; } }
    public string PartnerskyKod { get { return partnerskyKod; } set { partnerskyKod = value; } }
    public float CenaPredSlevou { get { return cenaPredSlevou; } set { cenaPredSlevou = value; } }
    public Slevy Slevy { get { return slevy; } set { slevy = value; } }
    public float CenaKonecna { get { return cenaKonecna; } set { cenaKonecna = value; } }
    public RezervaceStav StavRezervace { get { return stavRezervace; } set { stavRezervace = value; } }
    public DateTime ZacatekRezervace { get { return zacatekRezervace; } set { zacatekRezervace = value; } }
    public DateTime KonecRezervace { get { return konecRezervace; } set { konecRezervace = value; } }
    public string Poznamka { get { return poznamka; } set { poznamka = value; } }
    public string JineSdeleni { get { return jineSdeleni; } set { jineSdeleni = value; } }
}
