﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci s rezervací lyžařského kurzu
/// </summary>
public class RezervaceLyzarskehoKurzu : Rezervace
{
    protected int pocetOsob;
    protected string kurz;
    protected string zpetneHodnoceni;
    protected Instruktor preferovanyInstruktor;
    protected Instruktor skutecnyInstruktor;

    public int PocetOsob { get { return pocetOsob; } set { pocetOsob = value; } }
    public string Kurz { get { return kurz; } set { kurz = value; } }
    public string ZpetneHodnoceni { get { return zpetneHodnoceni; } set { zpetneHodnoceni = value; } }
    public Instruktor PreferovanyInstruktor { get { return preferovanyInstruktor; } set { preferovanyInstruktor = value; } }
    public Instruktor SkutecnyInstruktor { get { return skutecnyInstruktor; } set { skutecnyInstruktor = value; } }


    /// <summary>
    /// Rezervace lyžařského kurzu
    /// </summary>
    /// <param name="referencniCislo">Referenční číslo</param>
    /// <param name="zakaznik">Zákazník</param>
    public RezervaceLyzarskehoKurzu(int referencniCislo, Zakaznik zakaznik)
        : base(referencniCislo, zakaznik)
    {

    }

    /// <summary>
    /// Rezervace lyžařského kurzu
    /// </summary>
    /// <param name="zakaznik">Zákazník</param>
    /// <param name="pobocka">Pobočka</param>
    /// <param name="partnerskyKod">Partnerský kód</param>
    /// <param name="cenaPredSlevou">Cena před slevou</param>
    /// <param name="slevy">Slevy</param>
    /// <param name="cenaKonecna">Cena konečná</param>
    /// <param name="zacatekRezervace">Datum začátku rezervace</param>
    /// <param name="konecRezervace">Datum konce rezervace</param>
    /// <param name="pocetOsob">Počet osob</param>
    /// <param name="nazevKurzu">Název kurzu</param>
    /// <param name="preferovanyInstruktor">Preferovaný instruktor</param>
    /// <param name="poznamka">Poznámka (jiné sdělení)</param>
    public RezervaceLyzarskehoKurzu(Zakaznik zakaznik, Pobocka pobocka, string partnerskyKod,
        float cenaPredSlevou, Slevy slevy, float cenaKonecna,
        DateTime zacatekRezervace, DateTime konecRezervace, int pocetOsob, string kurz, Instruktor preferovanyInstruktor, string poznamka)
        : base(zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, zacatekRezervace, konecRezervace, poznamka)
    {
        this.pocetOsob = pocetOsob;
        this.kurz = kurz;
        this.preferovanyInstruktor = preferovanyInstruktor;
    }

    /// <summary>
    /// Rezervace lyžařského kurzu
    /// </summary>
    /// <param name="referencniCislo">Referenční číslo (id rezervace)</param>
    /// <param name="zakaznik">Zákazník</param>
    /// <param name="pobocka">Pobočka</param>
    /// <param name="partnerskyKod">Partnerský kód</param>
    /// <param name="cenaPredSlevou">Cena před slevou</param>
    /// <param name="slevy">Slevy</param>
    /// <param name="cenaKonecna">Cena konečná</param>
    /// <param name="zacatekRezervace">Datum začátku rezervace</param>
    /// <param name="konecRezervace">Datum konce rezervace</param>
    /// <param name="pocetOsob">Počet osob</param>
    /// <param name="nazevKurzu">Název kurzu</param>
    /// <param name="zpetneHodnceni">Zpětné hodnocení</param>
    /// <param name="preferovanyInstruktor">Preferovaný instruktor</param>
    /// <param name="skutecnyInstruktor">Skutečný instruktor</param>
    /// <param name="poznamka">Poznámka (jiné sdělení)</param>
    public RezervaceLyzarskehoKurzu(int referencniCislo, Zakaznik zakaznik, Pobocka pobocka, string partnerskyKod,
        float cenaPredSlevou, Slevy slevy, float cenaKonecna,
        DateTime zacatekRezervace, DateTime konecRezervace, int pocetOsob, string kurz, string zpetneHodnoceni, Instruktor preferovanyInstruktor, Instruktor skutecnyInstruktor, string poznamka)
        : base(zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, zacatekRezervace, konecRezervace, poznamka)
    {
        this.pocetOsob = pocetOsob;
        this.kurz = kurz;
        this.zpetneHodnoceni = zpetneHodnoceni;
        this.preferovanyInstruktor = preferovanyInstruktor;
        this.skutecnyInstruktor = skutecnyInstruktor;
    }

    /// <summary>
    /// Uloží rezervaci lyžařského kurzu do databáze
    /// </summary>
    /// <returns>True, v případě že uložení proběhlo úspěšně, false v neúspěšně</returns>
    public bool UlozitRezervaci()
    {
        if (base.UlozitRezervaci())
        {
            try
            {
                Databaze databaze = new Databaze();
                string cmdText = "";

                databaze.SetCommandText("DELETE FROM rezervaceLyzarskyKurz WHERE idRezervace='" + this.referencniCislo + "';");
                databaze.ExecuteReader();

                if (this.skutecnyInstruktor == null)
                {
                    if (preferovanyInstruktor.Id == "")
                        cmdText = " INSERT INTO rezervaceLyzarskyKurz (idRezervace, pocetOsob, kurz) VALUES " +
                            "(" + this.referencniCislo + ", '" + pocetOsob.ToString() + "', '" + kurz + "');";
                    else
                        cmdText = " INSERT INTO rezervaceLyzarskyKurz (idRezervace, pocetOsob, kurz, preferovanyInstruktor) VALUES " +
                            "(" + this.referencniCislo + ", '" + pocetOsob.ToString() + "', '" + kurz + "', '" + preferovanyInstruktor.Id + "');";
                }
                else
                {
                    if (preferovanyInstruktor.Id == "")
                        cmdText = " INSERT INTO rezervaceLyzarskyKurz (idRezervace, pocetOsob, kurz, skutecnyInstruktor) VALUES " +
                            "(" + this.referencniCislo + ", '" + pocetOsob.ToString() + "', '" + kurz + "', '" + this.skutecnyInstruktor.Id + "');";
                    else
                        cmdText = " INSERT INTO rezervaceLyzarskyKurz (idRezervace, pocetOsob, kurz, preferovanyInstruktor, skutecnyInstruktor) VALUES " +
                            "(" + this.referencniCislo + ", '" + pocetOsob.ToString() + "', '" + kurz + "', '" + preferovanyInstruktor.Id + "', '" + this.skutecnyInstruktor.Id + "');";
                }


                databaze.SetCommandText(cmdText);
                databaze.ExecuteReader();

                return true;
            }
            catch (Exception)
            {
                base.SmazatRezervaci();
                return false;
            }
        }
        else
            return false;
    }

    /// <summary>
    /// Načte rezervaci
    /// </summary>
    public bool NacistRezervaci()
    {

        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT pocetOsob, kurz, zpetneHodnoceni, preferovanyInstruktor, skutecnyInstruktor FROM rezervaceLyzarskyKurzView WHERE idRezervace=" + base.referencniCislo + ";");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                this.pocetOsob = int.Parse(reader["pocetOsob"].ToString());
                this.kurz = reader["kurz"].ToString();
                this.zpetneHodnoceni = reader["zpetneHodnoceni"].ToString();
                this.preferovanyInstruktor = new Instruktor(reader["preferovanyInstruktor"].ToString());
                this.skutecnyInstruktor = new Instruktor(reader["skutecnyInstruktor"].ToString());

                if (this.preferovanyInstruktor.Id != "")
                    this.preferovanyInstruktor = SpravceUzivatelu.NacistInstruktora(this.preferovanyInstruktor.Id);
                if (this.skutecnyInstruktor.Id != "")
                    this.skutecnyInstruktor = SpravceUzivatelu.NacistInstruktora(this.skutecnyInstruktor.Id);

                return base.NacistRezervaci();
            }
            return false;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Smaže rezervaci z databáze
    /// </summary>
    public bool SmazatRezervaci()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("DELETE FROM rezervaceLyzarskyKurz WHERE idrezervace=" + this.referencniCislo + ";");
            databaze.ExecuteReader();
            return base.SmazatRezervaci();
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Uloží hodnocení lyžařského kurzu.
    /// </summary>
    /// <returns><c>True</c>, v případě, že uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool UlozitHodnoceniLyzarskehoKurzu()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("UPDATE rezervaceLyzarskyKurz SET zpetneHodnoceni='" + this.zpetneHodnoceni + "' WHERE idRezervace='" + base.referencniCislo + "';");
            databaze.ExecuteReader();
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

}
