﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci s rezervací lyžařského vybavení
/// </summary>
public class RezervaceLyzarskehoVybaveni : Rezervace
{
    private ArrayList seznamPolozek;

    /// <summary>
    /// Rezervace lyžařského vybavení
    /// </summary>
    /// <param name="referencniCislo">Referenční číslo</param>
    /// <param name="zakaznik">Zákazník</param>
    public RezervaceLyzarskehoVybaveni(int referencniCislo, Zakaznik zakaznik)
        : base(referencniCislo, zakaznik)
    {

    }


    public ArrayList SeznamPolozek { get { return seznamPolozek; } set { seznamPolozek = value; } }

    /// <summary>
    /// Rezervace lyžařského vybavení
    /// </summary>
    /// <param name="zakaznik">Zákazník</param>
    /// <param name="pobocka">Pobočka</param>
    /// <param name="partnerskyKod">Partnerský kód</param>
    /// <param name="cenaPredSlevou">Cena před slevou</param>
    /// <param name="slevy">Slevy</param>
    /// <param name="cenaKonecna">Cena konečná</param>
    /// <param name="zacatekRezervace">Datum začátku rezervace</param>
    /// <param name="konecRezervace">Datum konce rezervace</param>
    /// <param name="rezervacePolozky">Seznam položek rezervace</param>
    /// <param name="poznamka">Poznámka (jiné sdělení)</param>
    public RezervaceLyzarskehoVybaveni(Zakaznik zakaznik, Pobocka pobocka, string partnerskyKod,
        float cenaPredSlevou, Slevy slevy, float cenaKonecna,
        DateTime zacatekRezervace, DateTime konecRezervace, ArrayList rezervacePolozky, string poznamka)
        : base(zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, zacatekRezervace, konecRezervace, poznamka)
    {
        seznamPolozek = rezervacePolozky;
    }


    /// <summary>
    /// Rezervace lyžařského vybavení
    /// </summary>
    /// <param name="referencniCislo">Referenční číslo (id rezervace)</param>
    /// <param name="zakaznik">Zákazník</param>
    /// <param name="pobocka">Pobočka</param>
    /// <param name="partnerskyKod">Partnerský kód</param>
    /// <param name="cenaPredSlevou">Cena před slevou</param>
    /// <param name="slevy">Slevy</param>
    /// <param name="cenaKonecna">Cena konečná</param>
    /// <param name="zacatekRezervace">Datum začátku rezervace</param>
    /// <param name="konecRezervace">Datum konce rezervace</param>
    /// <param name="rezervacePolozky">Položky rezervace</param>
    /// <param name="poznamka">Poznámka (jiné sdělení)</param>
    public RezervaceLyzarskehoVybaveni(int referencniCislo, Zakaznik zakaznik, Pobocka pobocka, string partnerskyKod,
        float cenaPredSlevou, Slevy slevy, float cenaKonecna,
        DateTime zacatekRezervace, DateTime konecRezervace, ArrayList rezervacePolozky, RezervaceStav stavRezervace, string poznamka)
        : base(referencniCislo, zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, zacatekRezervace, konecRezervace, stavRezervace, poznamka)
    {
        seznamPolozek = rezervacePolozky;
    }

    /// <summary>
    /// Uloží rezervaci lyžařského vybavevní do databáze
    /// </summary>
    /// <returns>True, v případě že uložení proběhlo úspěšně, false v neúspěšně</returns>
    public bool UlozitRezervaci()
    {
        if (base.UlozitRezervaci())
        {
            try
            {
                Databaze databaze = new Databaze();
                string cmdText = "";

                foreach (RezervaceLyzarskehoVybaveniPolozky vybaveni in this.seznamPolozek)
                {
                    cmdText += "INSERT INTO rezervaceVybaveni (idRezervace, typ, vyska, vaha, bota, cena) VALUES" +
                        "(" + base.ReferencniCislo + ", '" + vybaveni.Typ + "','" + vybaveni.Vyska + "','" + vybaveni.Vaha + "','" + vybaveni.VelikostBoty + "','" + vybaveni.Cena + "')";
                }

                databaze.SetCommandText(cmdText);
                databaze.ExecuteReader();

                return true;
            }
            catch (Exception)
            {
                base.SmazatRezervaci();
                return false;
            }
        }
        else
            return false;
    }

    /// <summary>
    /// Smaže rezervaci lyžařského vybavení z databáze
    /// </summary>
    /// <returns></returns>
    public bool SmazatRezervaci()
    {
        try
        {
            base.SmazatRezervaci();
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT FROM rezervaceVybaveni WHERE idRezervace=" + this.referencniCislo + ";");
            databaze.ExecuteReader();
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

    public bool NacistRezervaci()
    {

        try
        {
            if (this.seznamPolozek != null)
                this.seznamPolozek.Clear();
            else
                seznamPolozek = new ArrayList();
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT typ, vyska, vaha, bota, cena FROM rezervaceVybaveniView WHERE idRezervace=" + base.referencniCislo + ";");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                RezervaceLyzarskehoVybaveniPolozky polozka = new RezervaceLyzarskehoVybaveniPolozky(reader["typ"].ToString(), int.Parse(reader["vyska"].ToString()), int.Parse(reader["vaha"].ToString()), float.Parse(reader["bota"].ToString()), float.Parse(reader["cena"].ToString()));
                this.seznamPolozek.Add(polozka);
            }
            if (this.seznamPolozek.Count == 0)
                return false;
            return base.NacistRezervaci();
        }
        catch (Exception ex)
        {
            return false;
        }

        return false;
    }

}
