﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci se slevami
/// </summary>
public class Slevy
{
    private int idSlev;
    private float maximalniSleva;
    private float onLineRezervace;
    private float pouzitiParnerskehoKodu;
    private float vcasnaRezervace;
    private float pocetOsob;
    private DateTime platnostOd;
    private ArrayList slevyPocetOsob;

    /// <summary>
    /// Slevy
    /// </summary>
    public Slevy()
    {
        this.idSlev = 0;
        slevyPocetOsob = new ArrayList();
    }

    /// <summary>
    /// Slevy
    /// </summary>
    public Slevy(int idSlev)
    {
        this.idSlev = idSlev;
        slevyPocetOsob = new ArrayList();
    }

    /// <summary>
    /// Slevy.
    /// </summary>
    /// <param name="maximalniSleva">Maximální/celková sleva.</param>
    /// <param name="onlineRezervace">Sleva za online rezervaci.</param>
    /// <param name="pouzitiPartnerskehoKodu">Sleva za použití správného klientského kódu.</param>
    /// <param name="vcasnaRezervace">Sleva za včesnou rezervaci.</param>
    /// <param name="pocetOsob">Sleva za určitý počet osob.</param>
    public Slevy(float maximalniSleva, float onlineRezervace, float pouzitiPartnerskehoKodu, float vcasnaRezervace, float pocetOsob)
    {
        this.idSlev = 0;
        this.maximalniSleva = maximalniSleva;
        this.onLineRezervace = onlineRezervace;
        this.pouzitiParnerskehoKodu = pouzitiPartnerskehoKodu;
        this.vcasnaRezervace = vcasnaRezervace;
        this.pocetOsob = pocetOsob;
    }

    /// <summary>
    /// Slevy.
    /// </summary>
    /// <param name="idSlev">Id slev.</param>
    /// <param name="maximalniSleva">Maximální/celková sleva.</param>
    /// <param name="onlineRezervace">Sleva za online rezervaci.</param>
    /// <param name="pouzitiPartnerskehoKodu">Sleva za použití správného klientského kódu.</param>
    /// <param name="vcasnaRezervace">Sleva za včesnou rezervaci.</param>
    /// <param name="pocetOsob">Sleva za určitý počet osob.</param>
    /// <param name="platnostOd">Datum začátku platnosti slev.</param>
    /// <param name="seznamPocetOsob">Seznam slev pro počty osob.</param>
    public Slevy(int idSlev, DateTime platnostOd, float maximalniSleva, float onlineRezervace, float pouzitiPartnerskehoKodu, float vcasnaRezervace, ArrayList seznamPocetOsob)
    {
        this.idSlev = idSlev;
        this.maximalniSleva = maximalniSleva;
        this.onLineRezervace = onlineRezervace;
        this.pouzitiParnerskehoKodu = pouzitiPartnerskehoKodu;
        this.vcasnaRezervace = vcasnaRezervace;
        this.slevyPocetOsob = seznamPocetOsob;
        this.platnostOd = platnostOd;
    }

    /// <summary>
    /// Vrátí nebo nastaví maximální cenu.
    /// </summary>
    public float MaximalniSleva
    {
        get { return maximalniSleva; }
        set { maximalniSleva = value; }
    }

    /// <summary>
    /// Vrátí nebo nastavísleva za online rezervaci
    /// </summary>
    public float OnLineRezervace
    {
        get { return onLineRezervace; }
        set { onLineRezervace = value; }
    }

    /// <summary>
    /// Vrátí nebo nastavísleva za použití klientského kódu
    /// </summary>
    public float PouzitiPartnerskehoKodu
    {
        get { return pouzitiParnerskehoKodu; }
        set { pouzitiParnerskehoKodu = value; }
    }

    /// <summary>
    /// Vrátí nebo nastavísleva za vcasnou rezervaci
    /// </summary>
    public float VcasnaRezervace
    {
        get { return vcasnaRezervace; }
        set { vcasnaRezervace = value; }
    }

    /// <summary>
    /// Vrátí nebo nastavísleva za počet osob
    /// </summary>
    public float SlevaPocetOsob
    {
        get { return pocetOsob; }
        set { pocetOsob = value; }
    }

    /// <summary>
    /// Vrátí nebo nastavíseznam slev za určitý počet osob
    /// </summary>
    public ArrayList SlevyPocetOsob
    {
        get { return slevyPocetOsob; }
        set { slevyPocetOsob = value; }
    }

    /// <summary>
    /// Vrátí nebo nastaví začátek platnosti.
    /// </summary>
    public DateTime PlatnostOd
    {
        get { return platnostOd; }
        set { platnostOd = value; }
    }


    /// <summary>
    /// Načte aktuální ceny.
    /// </summary>
    /// <returns><c>True</c>, pokud načtení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool NacistSlevy()
    {
        Databaze databaze = new Databaze();
        try
        {
            if (this.idSlev == 0)
                databaze.SetCommandText("SELECT TOP 1 idSlev, maximalniSleva, platnostOd, onLineRezervace, pouzitiPartnerskehoKodu, vcasnaRezervace FROM slevy WHERE platnostOd<'" + DateTime.Today.ToString("yyyy-MM-dd") + "' ORDER BY platnostOd DESC;");
            else
                databaze.SetCommandText("SELECT idSlev, maximalniSleva, platnostOd, onLineRezervace, pouzitiPartnerskehoKodu, vcasnaRezervace FROM slevy WHERE idSlev='" + this.idSlev + "';");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                this.idSlev = int.Parse(reader["idSlev"].ToString());
                this.maximalniSleva = float.Parse(reader["maximalniSleva"].ToString());
                this.onLineRezervace = float.Parse(reader["onLineRezervace"].ToString());
                this.pouzitiParnerskehoKodu = float.Parse(reader["pouzitiPartnerskehoKodu"].ToString());
                this.vcasnaRezervace = float.Parse(reader["vcasnaRezervace"].ToString());
                this.PlatnostOd = DateTime.Parse(reader["platnostOd"].ToString());
            }

            this.SlevyPocetOsob.Clear();
            databaze.SetCommandText("SELECT pocetOsob, sleva FROM slevyPocetOsob WHERE idSlev=" + this.idSlev + " ORDER BY pocetOsob DESC;");
            reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                PolozkaSlevyPocetOsob slevaPocetOsob = new PolozkaSlevyPocetOsob();
                slevaPocetOsob.PocetOsob = int.Parse(reader["pocetOsob"].ToString());
                slevaPocetOsob.Sleva = int.Parse(reader["sleva"].ToString());
                this.SlevyPocetOsob.Add(slevaPocetOsob);
            }
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Vypočítá slevu za počet osob.
    /// </summary>
    /// <param name="pocetOsob">Počet osob.</param>
    /// <returns>Sleva za počet osob.</returns>
    public float VypocitatSlevuZaPocetOsob(int pocetOsob)
    {
        foreach (PolozkaSlevyPocetOsob sleva in this.slevyPocetOsob)
        {
            if (pocetOsob >= sleva.PocetOsob)
                return sleva.Sleva;
        }
        return 0;
    }

    /// <summary>
    /// Vypočítá slevu za vcasnou rezervaci.
    /// </summary>
    /// <param name="pocetDni">Počet dní, které zbývají do rezervace.</param>
    /// <returns>Sleva uplatněná za včasnou rezervaci.</returns>
    public float VypocitatSlevuZaVcasnouRezervaci(int pocetDni)
    {
        return (float)(Math.Floor((double)(pocetDni / 30)) * this.vcasnaRezervace);
    }

    /// <summary>
    /// Vypočítá slevu za zadaný partnerský kód.
    /// </summary>
    /// <param name="partnerskyKod">Zadaný partnerský kód.</param>
    /// <returns>Výše slevy.</returns>
    public float VypocitatSlevuZaPartnerskyKod(string partnerskyKod)
    {
        if (SpravceUzivatelu.ExistujePartnerskyKod(partnerskyKod))
            return this.pouzitiParnerskehoKodu;
        else
            return 0;
    }

    /// <summary>
    /// Vypočítá konečnou slevu rezervace.
    /// </summary>
    /// <param name="slevaZaPocetOsob">Sleva za počet osob.</param>
    /// <param name="slevaZaVcasnouRezervaci">Sleva za vcasnou rezervaci.</param>
    /// <param name="slevaZaPartnerskyKod">Sleva za partnersky kod.</param>
    /// <returns>Konečná sleva.</returns>
    public float VypocitatKonecnouSlevu(float slevaZaPocetOsob, float slevaZaVcasnouRezervaci, float slevaZaPartnerskyKod)
    {
        float konecnaSleva = this.onLineRezervace + slevaZaPocetOsob + slevaZaVcasnouRezervaci + slevaZaPartnerskyKod;
        if (konecnaSleva > this.maximalniSleva)
            return this.maximalniSleva;
        return konecnaSleva;
    }

    /// <summary>
    /// Uloží slevy do databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool UlozitSlevy()
    {
        try
        {
            Databaze databaze = new Databaze();
            SqlCommand cmd;
            if (this.idSlev != 0)
            {
                cmd = new SqlCommand("UPDATE slevy SET platnostOd='" + this.platnostOd.ToString("yyyy-MM-dd") + "', " +
                    " maximalniSleva=@maximalniSleva, onLineRezervace=@onLineRezervace, pouzitiPartnerskehoKodu=@pouzitiPartnerskehoKodu, vcasnaRezervace=@vcasnaRezervace " +
                    "WHERE idSlev='" + this.idSlev + "';");
            }
            else
            {
                databaze.SetCommandText("SELECT MAX(idSlev) AS max FROM slevy");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                    if (int.TryParse(reader["max"].ToString(), out this.idSlev))
                        this.idSlev = int.Parse(reader["max"].ToString());
                this.idSlev += 1;

                cmd = new SqlCommand("INSERT INTO slevy (idSlev, platnostOd, maximalniSleva, onLineRezervace, pouzitiPartnerskehoKodu, vcasnaRezervace) VALUES " +
                        "('" + this.idSlev + "', '" + this.platnostOd.ToString("yyyy-MM-dd") + "', @maximalniSleva, @onLineRezervace, @pouzitiPartnerskehoKodu , @vcasnaRezervace);");
            }
            SqlParameter parametr = new SqlParameter("@maximalniSleva", this.maximalniSleva);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@onLineRezervace", this.onLineRezervace);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@pouzitiPartnerskehoKodu", this.pouzitiParnerskehoKodu);
            cmd.Parameters.Add(parametr);
            parametr = new SqlParameter("@vcasnaRezervace", this.vcasnaRezervace);
            cmd.Parameters.Add(parametr);

            databaze.SetCommand(cmd);
            databaze.ExecuteReader();

            databaze.SetCommandText("DELETE FROM slevyPocetOsob WHERE idSlev='" + this.idSlev + "'");
            databaze.ExecuteReader();

            foreach (PolozkaSlevyPocetOsob polozka in this.slevyPocetOsob)
            {
                cmd = new SqlCommand("INSERT INTO slevyPocetOsob (idSlev, pocetOsob, sleva) VALUES ('" + this.idSlev + "', '" + polozka.PocetOsob + "', @sleva);");
                parametr = new SqlParameter("@sleva", polozka.Sleva);
                cmd.Parameters.Add(parametr);
                databaze.SetCommand(cmd);
                databaze.ExecuteReader();
            }

            return true;
        }
        catch (Exception ex)
        {
            return false;
        }
    }

    /// <summary>
    /// Smaže slevy z databáze.
    /// </summary>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public bool SmazatSlevy()
    {
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("DELETE FROM slevy WHERE idSlev='" + this.idSlev + "';");
            databaze.ExecuteReader();
            databaze.SetCommandText("DELETE FROM slevyPocetOsob WHERE idSlev='" + this.idSlev + "'");
            databaze.ExecuteReader();
            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }
}
