﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections;
using System.Data.SqlClient;

/// <summary>
/// Třída spravující ceníky a slevy.
/// </summary>
public static class SpravceCeniku
{
    
    /// <summary>
    /// Vypočítá cenu kurzu pro jednu osobu za určitý počet dní
    /// </summary>
    /// <param name="idKurzu">Id kurzu</param>
    /// <param name="pocetDniKurzu">Počet dní kurzu</param>
    /// <returns>Cena za počet dní kurzu</returns>
    public static float VypocitatCenuKurzu(int idKurzu, int pocetDniKurzu)
    {
        CenikKurzu cenik = new CenikKurzu(idKurzu);
        cenik.NacistCenikKurzu(true);
        return cenik.VypocitatCenuKurzu(pocetDniKurzu);
    }




    /// <summary>
    /// Vypočítá cenu vybavení za určitý počet dní
    /// </summary>
    /// <param name="idVybaveni">Id vybavení</param>
    /// <param name="pocetDni">Počet dní</param>
    /// <returns>Cena vybavení</returns>
    public static float VypocitatCenuVybaveni(int idVybaveni, int pocetDni)
    {
        CenikLyzarskehoVybaveni cenik = new CenikLyzarskehoVybaveni(idVybaveni);
        cenik.NacistCenikLyzarskehoVybaveni();
        return cenik.VypocitejCenuVybaveni(pocetDni);
    }



    /// <summary>
    /// Načte slevy.
    /// </summary>
    /// <returns>Slevy.</returns>
    public static Slevy NacistSlevy()
    {
        Slevy slevy = new Slevy();
        if (slevy.NacistSlevy())
            return slevy;
        return null;
    }

    /// <summary>
    /// Načte slevy.
    /// </summary>
    /// <param name="idSlev">Id slev.</param>
    /// <returns>Slevy.</returns>
    public static Slevy NacistSlevy(int idSlev)
    {
        Slevy slevy = new Slevy(idSlev);
        if (slevy.NacistSlevy())
            return slevy;
        return null;
    }


    /// <summary>
    /// Načte ceník skibalíčků.
    /// </summary>
    /// <returns>Ceník skibalíčků.</returns>
    public static DataSet NacistCenikSkibalicku()
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idSkiBalicku, nazevSkiBalicku, pocetDniKurzu, pocetDniVybaveni, cena, nazev AS nazevKurzu FROM cenikSkibalicekView;", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte slevy.
    /// </summary>
    /// <returns>Slevy.</returns>
    public static DataSet NacistSeznamSlev()
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idSlev, platnostOd, maximalniSleva, onLineRezervace, pouzitiPartnerskehoKodu, vcasnaRezervace FROM slevy;", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte lyžařské kurzy.
    /// </summary>
    /// <returns>Lyžařské kurzy.</returns>
    public static DataSet NacistLyzarskeKurzy()
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idKurzu, nazev, info FROM kurz;", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte lyžařské vybavení.
    /// </summary>
    /// <returns>Lyžařské Vybavení.</returns>
    public static DataSet NacistLyzarskeVybaveni()
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idVybaveni, nazev, info, pojistne FROM lyzarskeVybaveni;", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }


    /// <summary>
    /// Načte ceník skibalíčku.
    /// </summary>
    /// <param name="idSkibalicku">Id skibalíčku, který se má načíst.</param>
    /// <returns>Ceník skibalíčku.</returns>
    public static CenikSkibalicku NacistCenikSkibalicku(int idSkibalicku)
    {
        CenikSkibalicku cenikSkibalicku = new CenikSkibalicku(idSkibalicku);
        if (cenikSkibalicku.NacistSkibalicek())
            return cenikSkibalicku;
        return null;
    }

    /// <summary>
    /// Načte ceník lyžařského kurzu.
    /// </summary>
    /// <param name="idKurzu">Id kurzu, který se má načíst.</param>
    /// <param name="polozky"><c>True</c>, pokud se mají načíst i položky ceníku, jinak <c>false</c>.</param>
    /// <returns>Ceník kurzu.</returns>
    public static CenikKurzu NacistCenikKurzu(int idKurzu, bool polozky)
    {
        CenikKurzu cenikKurzu = new CenikKurzu(idKurzu);
        if (cenikKurzu.NacistCenikKurzu(polozky))
            return cenikKurzu;
        return null;
    }

    /// <summary>
    /// Načte ceník lyžařského vybavení.
    /// </summary>
    /// <param name="idVybaveni">Id vybavení, které se má načíst.</param>
    /// <returns>Ceník vybavení.</returns>
    public static CenikLyzarskehoVybaveni NacistCenikLyzarskehoVybaveni(int idVybaveni)
    {
        CenikLyzarskehoVybaveni cenikVybaveni = new CenikLyzarskehoVybaveni(idVybaveni);
        if (cenikVybaveni.NacistCenikLyzarskehoVybaveni())
            return cenikVybaveni;
        return null;
    }

    /// <summary>
    /// Načte ceníky kurzů.
    /// </summary>
    /// <returns>Ceníky kurzů.</returns>
    public static ArrayList NacistCenikyKurzu()
    {
        ArrayList cenikyKurzu = new ArrayList();
        Databaze databaze = new Databaze();
        databaze.SetCommandText("SELECT idKurzu FROM kurz ORDER BY nazev;");
        SqlDataReader reader = databaze.ExecuteReader();
        while (reader.Read())
        {
            CenikKurzu cenik = new CenikKurzu(int.Parse(reader["idKurzu"].ToString()));
            cenik.NacistCenikKurzu(true);
            cenikyKurzu.Add(cenik);
        }
        return cenikyKurzu;
    }

    /// <summary>
    /// Načte ceníky kurzů.
    /// </summary>
    /// <returns>Ceníky kurzů.</returns>
    public static ArrayList NacistCenikyLyzarskeVybaveni()
    {
        ArrayList cenikyVybaveni = new ArrayList();
        Databaze databaze = new Databaze();
        databaze.SetCommandText("SELECT idVybaveni FROM lyzarskeVybaveni ORDER BY nazev;");
        SqlDataReader reader = databaze.ExecuteReader();
        while (reader.Read())
        {
            CenikLyzarskehoVybaveni cenik = new CenikLyzarskehoVybaveni(int.Parse(reader["idVybaveni"].ToString()));
            cenik.NacistCenikLyzarskehoVybaveni();
            cenikyVybaveni.Add(cenik);
        }
        return cenikyVybaveni;
    }

    /// <summary>
    /// Uloží ceník skibalíčku.
    /// </summary>
    /// <param name="idSkibalicku">Id skibalíčku, pokud je skibalíček nový, pak 0.</param>
    /// <param name="nazevSkibalicku">Název skibalíčku.</param>
    /// <param name="idKurzu">id kurzu.</param>
    /// <param name="pocetDniKurzu">Počet dní kurzu.</param>
    /// <param name="pocetDniVybaveni">Počet dní vybavení.</param>
    /// <param name="cena">Cena za skibalíček.</param>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool UlozitCenikSkibalicku(int idSkibalicku, string nazevSkibalicku, int idKurzu, int pocetDniKurzu, int pocetDniVybaveni, float cena)
    {
        CenikSkibalicku skibalicek = new CenikSkibalicku(idSkibalicku, nazevSkibalicku, new CenikKurzu(idKurzu), pocetDniKurzu, pocetDniVybaveni, cena);
        return skibalicek.UlozitSkibalicek();
    }

    /// <summary>
    /// Uloží ceník lyžařského kurzu.
    /// </summary>
    /// <param name="idKurzu">Id kurzu.</param>
    /// <param name="info">Informace o kurzu.</param>
    /// <param name="nazev">Název kurzu.</param>
    /// <param name="polozkyKurzu">Položky kurzu.</param>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool UlozitCenikLyzarskehoKurzu(int idKurzu, string nazev, string info, ArrayList polozkyKurzu)
    {
        CenikKurzu kurz = new CenikKurzu(idKurzu, nazev, info);
        kurz.PolozkyCeniku = polozkyKurzu;
        return kurz.UlozitCenikKurzu();
    }

    /// <summary>
    /// Uloží ceník lyžařského vybavení.
    /// </summary>
    /// <param name="idVybaveni">Id vybaveni.</param>
    /// <param name="info">Informace o vybavení.</param>
    /// <param name="nazev">Název vybavení.</param>
    /// <param name="pojistne">Pojistné za den.</param>
    /// <param name="polozkyVybaveni">Položky vybavení (ceny).</param>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool UlozitCenikLyzarskehoVybaveni(int idVybaveni, string nazev, string info, float pojistne, ArrayList polozkyVybaveni)
    {
        CenikLyzarskehoVybaveni vybaveni = new CenikLyzarskehoVybaveni(idVybaveni, nazev, info, pojistne);
        vybaveni.PolozkyCeniku = polozkyVybaveni;
        return vybaveni.UlozitCenikVybaveni();
    }


    public static bool UlozitSlevy(int idSlev, DateTime platnostOd, float maximalniSleva, float onLineRezervace, float pouzitiPartnerskehoKodu, float vcasnaRezervace, ArrayList seznamPocetOsob)
    {
        Slevy slevy = new Slevy(idSlev, platnostOd, maximalniSleva, onLineRezervace, pouzitiPartnerskehoKodu, vcasnaRezervace, seznamPocetOsob);
        return slevy.UlozitSlevy();
    }

    /// <summary>
    /// Smaže skibalíček z databáze.
    /// </summary>
    /// <param name="idSkibalicku">Id skibalíčku, který se má smazat.</param>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool SmazatCenikSkibalicku(int idSkibalicku)
    {
        CenikSkibalicku skibalicek = new CenikSkibalicku(idSkibalicku);
        return skibalicek.SmazatSkibalicek();
    }

    /// <summary>
    /// Smaže ceník kurzu z databáze.
    /// </summary>
    /// <param name="idKurzu">Id kurzu, který se má smazat.</param>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool SmazatCenikKurzu(int idKurzu)
    {
        CenikKurzu kurz = new CenikKurzu(idKurzu);
        return kurz.SmazatCenikKurzu();
    }

    /// <summary>
    /// Smaže ceník lyžařského vybavení z databáze.
    /// </summary>
    /// <param name="idVybaveni">Id vybavení, které se má smazat.</param>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool SmazatCenikLyzarskehoVybaveni(int idVybaveni)
    {
        CenikLyzarskehoVybaveni vybaveni = new CenikLyzarskehoVybaveni(idVybaveni);
        return vybaveni.SmazatCenikVybaveni();
    }

    /// <summary>
    /// Smaže slevy z databáze.
    /// </summary>
    /// <param name="idSlev">Id slev, které mají být smazány.</param>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool SmazatSlevy(int idSlev)
    {
        Slevy slevy = new Slevy(idSlev);
        return slevy.SmazatSlevy();
    }


}


