﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Data.SqlClient;
using System.Collections;

/// <summary>
/// Třída spravující rezervace.
/// </summary>
public static class SpravceRezervaci
{

    /// <summary>
    /// Vytvoří rezervaci lyžařského vybavení a uloží ji do databáze.
    /// </summary>
    /// <param name="zakaznik">Zákazník.</param>
    /// <param name="pobocka">Pobočka.</param>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <param name="cenaPredSlevou">Cena před slevou.</param>
    /// <param name="slevy">Slevy.</param>
    /// <param name="cenaKonecna">Konečná cena.</param>
    /// <param name="rezervaceOd">Začátek rezervace.</param>
    /// <param name="rezervaceDo">Konec rezervace.</param>
    /// <param name="polozkyRezervaceVybaveni">Položky rezervace (jednotlivé sety).</param>
    /// <param name="poznamka">Poznámka (jiné sdělení zákazníka).</param>
    /// <returns><c>True</c> v případě, že vytvoření rezervace proběhlo úspěšně, jinak <c>False</c>.</returns>
    public static bool VytvoritRezervaciLyzarskehoVybaveni(Zakaznik zakaznik, Pobocka pobocka, string partnerskyKod, float cenaPredSlevou, Slevy slevy, float cenaKonecna, DateTime rezervaceOd, DateTime rezervaceDo, ArrayList rezervacePolozky, string poznamka)
    {
        RezervaceLyzarskehoVybaveni rezervace = new RezervaceLyzarskehoVybaveni(zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, rezervaceOd, rezervaceDo, rezervacePolozky, poznamka);
        if (rezervace.UlozitRezervaci())
        {
            SpravceRezervaci.PoslatEmailZakaznikovi(rezervace);
            if (rezervace.PartnerskyKod != "")
                SpravceRezervaci.PoslatEmailPartnerovi(rezervace);
            return true;
        }
        return false;
    }

    /// <summary>
    /// Vytvoří rezervaci lyžařské výuky.
    /// </summary>
    /// <param name="zakaznik">Zákazník.</param>
    /// <param name="pobocka">Pobočka.</param>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <param name="cenaPredSlevou">Cena před slevou.</param>
    /// <param name="slevy">Slevy.</param>
    /// <param name="cenaKonecna">Konečná cena.</param>
    /// <param name="rezervaceOd">Začátek rezervace.</param>
    /// <param name="rezervaceDo">Konec rezervace.</param>
    /// <param name="pocetOsob">Počet osob.</param>
    /// <param name="kurz">Kurz.</param>
    /// <param name="preferovanyInstruktor">Preferovaný instruktor.</param>
    /// <param name="poznamka">Poznámka (jiné sdělení zákazníka).</param>
    /// <returns><c>True</c> v případě, že vytvoření rezervace proběhlo úspěšně, jinak <c>False</c>.</returns>
    public static bool VytvoritRezervaciLyzarskeVyuky(Zakaznik zakaznik, Pobocka pobocka, string partnerskyKod, float cenaPredSlevou, Slevy slevy, float cenaKonecna, DateTime rezervaceOd, DateTime rezervaceDo, int pocetOsob, string kurz, string preferovanyInstruktor, string poznamka)
    {

        RezervaceLyzarskehoKurzu rezervace = new RezervaceLyzarskehoKurzu(zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, rezervaceOd, rezervaceDo, pocetOsob, kurz, new Instruktor(preferovanyInstruktor), poznamka);
        if (rezervace.UlozitRezervaci())
        {
            SpravceRezervaci.PoslatEmailZakaznikovi(rezervace);
            if (rezervace.PartnerskyKod != "")
                SpravceRezervaci.PoslatEmailPartnerovi(rezervace);
            return true;
        }
        return false;
    }

    /// <summary>
    /// Vytvoří rezervaci skibalíčku.
    /// </summary>
    /// <param name="zakaznik">Zákazník.</param>
    /// <param name="pobocka">Pobočka.</param>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <param name="cenaPredSlevou">Cena před slevou.</param>
    /// <param name="slevy">Slevy.</param>
    /// <param name="cenaKonecna">Konečná cena.</param>
    /// <param name="rezervaceOd">Začátek rezervace.</param>
    /// <param name="rezervaceDo">Konec rezervace.</param>
    /// <param name="pocetOsob">Počet osob.</param>
    /// <param name="skibalicek">Skibalíček.</param>
    /// <param name="preferovanyInstruktor">Preferovaný instruktor.</param>
    /// <param name="polozkyRezervaceVybaveni">Položky rezervace (jednotlivé sety).</param>
    /// <param name="poznamka">Poznámka (jiné sdělení zákazníka).</param>
    /// <returns><c>True</c> v případě, že vytvoření rezervace proběhlo úspěšně, jinak <c>False</c>.</returns>
    public static bool VytvoritRezervaciSkibalicku(Zakaznik zakaznik, Pobocka pobocka, string partnerskyKod, float cenaPredSlevou, Slevy slevy, float cenaKonecna, DateTime rezervaceOd, DateTime rezervaceDo, int pocetOsob, string skibalicek, string preferovanyInstruktor, ArrayList polozkyRezervaceVybaveni, string poznamka)
    {
        RezervaceLyzarskehoKurzu rezervaceKurzu = new RezervaceLyzarskehoKurzu(zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, rezervaceOd, rezervaceDo, pocetOsob, skibalicek, new Instruktor(preferovanyInstruktor), poznamka);

        if (rezervaceKurzu.UlozitRezervaci())
        {
            RezervaceLyzarskehoVybaveni rezervaceVybaveni = new RezervaceLyzarskehoVybaveni(rezervaceKurzu.ReferencniCislo, zakaznik, pobocka, partnerskyKod, cenaPredSlevou, slevy, cenaKonecna, rezervaceOd, rezervaceDo, polozkyRezervaceVybaveni, new RezervaceStav(-1), poznamka);
            if (rezervaceVybaveni.UlozitRezervaci())
                return true;
            else
                rezervaceKurzu.SmazatRezervaci();

        }
        return false;
    }

    /// <summary>
    /// Odešle informativní email partnerovi.
    /// </summary>
    /// <param name="rezervace">Rezervace.</param>
    public static void PoslatEmailPartnerovi(object rezervace)
    {
        try
        {
            Partner partner = SpravceUzivatelu.NactiPartnera(SpravceUzivatelu.NacistIdPartneraPodlePartnerskehoKodu(((Rezervace)rezervace).PartnerskyKod));
            string strTo = partner.Email;
            
            string strSubject = "Rezervace lyžařské školy";

            string strBody = "<h1>Rezervace s Vaším partnerským kódem</h1>";
            strBody += "<p>Vážený partnere,<br />dovolujeme si Vám oznámit, že se právě uskutečnila rezervace č. " + ((Rezervace)rezervace).ReferencniCislo.ToString() + ", u které byl zadán Váš partnerský kód. Stav vyřízení rezervací a Vašich provizí můžete sledovat po přihlášení na našich internetových stránkách.</p>";



            System.Net.Mail.MailMessage message = new System.Net.Mail.MailMessage();
            message.From = new System.Net.Mail.MailAddress(strTo);
            message.IsBodyHtml = true;
            message.Subject = strSubject;
            message.Body = strBody;

            /*            
            smtp.Host = "localhost";
             */
            System.Net.Mail.SmtpClient smtp = new System.Net.Mail.SmtpClient();
            smtp.Send(message);
        }
        catch (Exception e)
        {

        }
    }

    /// <summary>
    /// Odešle informativní email zákazníkovi.
    /// </summary>
    /// <param name="rezervace">Rezervace.</param>
    public static void PoslatEmailZakaznikovi(object rezervace)
    {
        try
        {
            string strTo = ((Rezervace)rezervace).Zakaznik.Email;
            string strSubject = "Rezervace lyžařské školy";


            string strBody = "";

            switch (rezervace.GetType().ToString())
            {
                case "RezervaceLyzarskehoKurzu":
                    strBody = "<h1>Rezervace výuky lyžařské školy</h1>";
                    break;
                case "RezervaceLyzarskehoVybaveni":
                    strBody = "<h1>Rezervace lyžařského vybavení</h1>";
                    break;
                case "Rezervace":
                    strBody = "<h1>Rezervace skibalíčku</h1>";
                    break;
                default:
                    break;
            }

            strBody += "<h2>Referenční číslo rezervace: " + ((Rezervace)rezervace).ReferencniCislo.ToString() + "</h2>" +
                "<p>Vážený zákazníku,<br />děkujeme Vám za důvěru v naši lyžařskou školu. Tímto potvrzujeme, že jsme přijali Vaši rezervaci. Stav vyřízení Vaší rezervaci můžete sledovat online po přihlášení na našich internetových stránkách.</p>";


            strBody += "";


            System.Net.Mail.MailMessage message = new System.Net.Mail.MailMessage();
            message.From = new System.Net.Mail.MailAddress(strTo);
            message.IsBodyHtml = true;
            message.Subject = strSubject;
            message.Body = strBody;

            System.Net.Mail.SmtpClient smtp = new System.Net.Mail.SmtpClient();
            smtp.Send(message);
        }
        catch (Exception e)
        {

        }
    }


    /// <summary>
    /// Načte rezervace uskutečněné zákazníkem.
    /// </summary>
    /// <returns>Ceník skibalíčků.</returns>
    public static DataSet NactiSeznamRezervaciZakaznika(string idUzivatele)
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idRezervace, od, do, nazevPobocky, cenaPredSlevou, slevaCelkem, cenaKonecna, stavRezervace FROM rezervaceStavView WHERE idZakaznika='" + idUzivatele + "';", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte stavy rezervací.
    /// </summary>
    /// <returns>Stavy rezervací.</returns>
    public static DataSet NacistStavyRezervaci()
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idStavuRezervace, stavRezervace, info FROM rezervaceStav;", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte stavy rezervací.
    /// </summary>
    /// <param name="idStavu">Id stavu rezervace, který se má načíst.</param>
    /// <returns>Stav rezervace.</returns>
    public static RezervaceStav NacistStavRezervace(int stavRezervace)
    {
        RezervaceStav stav = new RezervaceStav(stavRezervace);
        if (stav.NacistStavRezervace())
            return stav;
        return null;
    }

    /// <summary>
    /// Načte rezervace, které vyučoval instruktor.
    /// </summary>
    /// <returns>Rezervace.</returns>
    public static DataSet NactiSeznamRezervaciInstruktora(string idUzivatele)
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idRezervace, od, do, nazevPobocky, cenaPredSlevou, slevaCelkem, cenaKonecna, stavRezervace FROM rezervaceInstruktorView WHERE skutecnyInstruktor='" + idUzivatele + "';", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte rezervace, které vyučoval instruktor.
    /// </summary>
    /// <returns>Rezervace.</returns>
    public static DataSet NacistSeznamRezervaciPodleStavuRezervace(string idStavuRezervace)
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idRezervace, od, do, nazevPobocky, cenaPredSlevou, slevaCelkem, cenaKonecna FROM prehledRezervaciView WHERE idStavuRezervace='" + idStavuRezervace + "';", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte rezervaci lyžařskského kurzu.
    /// </summary>
    /// <param name="rezervace">Rezervace, která má být načtena.</param>
    /// <returns>Rezervace lyžařského kurzu, pokud neexistuje, tak <c>null</c>.</returns>
    private static RezervaceLyzarskehoKurzu NactiRezervaciLyzarskehoKurzu(RezervaceLyzarskehoKurzu rezervace)
    {
        if (rezervace.NacistRezervaci())
            return rezervace;
        else
            return null;
    }

    /// <summary>
    /// Načte rezervaci lyžařskského kurzu zákazníka.
    /// </summary>
    /// <param name="idRezervace">Id rezervace kurzu, který se má načíst.</param>
    /// <param name="idZakaznika">Id zákazníka, který rezervaci provedl.</param>
    /// <returns>Rezervace lyžařského kurzu, pokud neexistuje, tak <c>null</c>.</returns>
    public static RezervaceLyzarskehoKurzu NacistRezervaciLyzarskehoKurzuZakaznika(int idRezervace, string idZakaznika)
    {
        Zakaznik zakaznik = new Zakaznik(idZakaznika);
        RezervaceLyzarskehoKurzu rezervace = new RezervaceLyzarskehoKurzu(idRezervace, zakaznik);
        rezervace = NactiRezervaciLyzarskehoKurzu(rezervace);
        if (rezervace != null)
            if (rezervace.Zakaznik.Id == idZakaznika)
                return rezervace;
        return null;
    }

    /// <summary>
    /// Načte rezervaci lyžařskského kurzu.
    /// </summary>
    /// <param name="idRezervace">Id rezervace kurzu, který se má načíst.</param>
    /// <returns>Rezervace lyžařského kurzu, pokud neexistuje, tak <c>null</c>.</returns>
    public static RezervaceLyzarskehoKurzu NacistRezervaciLyzarskehoKurzu(int idRezervace)
    {
        RezervaceLyzarskehoKurzu rezervace = new RezervaceLyzarskehoKurzu(idRezervace, null);
        rezervace = NactiRezervaciLyzarskehoKurzu(rezervace);
        if (rezervace != null)
            return rezervace;
        return null;
    }

    /// <summary>
    /// Načte rezervaci lyžařskského kurzu instruktora.
    /// </summary>
    /// <param name="idRezervace">Id rezervace kurzu, který se má načíst.</param>
    /// <param name="idZakaznika">Id instruktora, který rezervaci vyučoval.</param>
    /// <returns>Rezervace lyžařského kurzu, pokud neexistuje, tak <c>null</c>.</returns>
    public static RezervaceLyzarskehoKurzu NacistRezervaciLyzarskehoKurzuInstruktora(int idRezervace, string idInstruktora)
    {
        Zakaznik zakaznik = new Zakaznik("");
        RezervaceLyzarskehoKurzu rezervace = new RezervaceLyzarskehoKurzu(idRezervace, zakaznik);
        rezervace = NactiRezervaciLyzarskehoKurzu(rezervace);
        if (rezervace != null)
            if (rezervace.SkutecnyInstruktor.Id == idInstruktora)
                return rezervace;
        return null;
    }

    /// <summary>
    /// Načte rezervaci lyžařského vybavení.
    /// </summary>
    /// <param name="idRezervace">Id rezervace lyžařského vybavení, která se má načíst.</param>
    /// <param name="idZakaznika">Id zákazníka, který rezervaci provedl.</param>
    /// <returns>Rezervace lyžařského vybavení, pokud neexistuje, tak <c>null</c>.</returns>
    private static RezervaceLyzarskehoVybaveni NacistRezervaciLyzarskehoVybaveni(RezervaceLyzarskehoVybaveni rezervace)
    {
        if (rezervace.NacistRezervaci())
            return rezervace;
        else
            return null;
    }

    /// <summary>
    /// Načte rezervaci lyžařskského vybavení zákazníka.
    /// </summary>
    /// <param name="idRezervace">Id rezervace kurzu, který se má načíst.</param>
    /// <param name="idZakaznika">Id zákazníka, který rezervaci provedl.</param>
    /// <returns>Rezervace lyžařského kurzu, pokud neexistuje, tak <c>null</c>.</returns>
    public static RezervaceLyzarskehoVybaveni NacistRezervaciLyzarskehoVybaveniZakaznika(int idRezervace, string idZakaznika)
    {
        Zakaznik zakaznik = new Zakaznik(idZakaznika);
        RezervaceLyzarskehoVybaveni rezervace = new RezervaceLyzarskehoVybaveni(idRezervace, zakaznik);
        rezervace = NacistRezervaciLyzarskehoVybaveni(rezervace);
        if (rezervace != null)
            if (rezervace.Zakaznik.Id == idZakaznika)
                return rezervace;
        return null;
    }

    /// <summary>
    /// Načte rezervaci lyžařskského vybavení zákazníka.
    /// </summary>
    /// <param name="idRezervace">Id rezervace kurzu, který se má načíst.</param>
    /// <returns>Rezervace lyžařského kurzu, pokud neexistuje, tak <c>null</c>.</returns>
    public static RezervaceLyzarskehoVybaveni NacistRezervaciLyzarskehoVybaveni(int idRezervace)
    {
        RezervaceLyzarskehoVybaveni rezervace = new RezervaceLyzarskehoVybaveni(idRezervace, null);
        rezervace = NacistRezervaciLyzarskehoVybaveni(rezervace);
        if (rezervace != null)
                return rezervace;
        return null;
    }

    /// <summary>
    /// Uloží hodnocení lyžařského kurzu.
    /// </summary>
    /// <param name="idRezervace">Id rezervace lyžařského kurzu, který se má ohodnotit.</param>
    /// <param name="hodnoceni">Hodnocení lyžařského kurzu.</param>
    /// <returns><c>True</c> v případě, že uložení proběhlo v pořádku, jinak <c>False</c>.</returns>
    public static bool UlozitHodnoceniKurzu(int idRezervace, Zakaznik zakaznik, string hodnoceni)
    {
        RezervaceLyzarskehoKurzu rezervace = new RezervaceLyzarskehoKurzu(idRezervace, zakaznik);
        rezervace.ZpetneHodnoceni = hodnoceni;
        return rezervace.UlozitHodnoceniLyzarskehoKurzu();
    }


    /// <summary>
    /// Smaže všechny rezervace uživatele.
    /// </summary>
    /// <param name="idUser">Id uživatele, kterému se mají smazat rezervace.</param>
    /// <returns><c>True</c> v případě, že smazání proběhlo v pořádku, jinak <c>False</c>.</returns>
    public static bool SmazatRezervaceUzivatele(string idUser)
    {

        DataSet seznamRezervaci = SpravceRezervaci.NactiSeznamRezervaciZakaznika(idUser);
        Databaze databaze = new Databaze();

        foreach (DataTable rezervaceTable in seznamRezervaci.Tables)
        {
            foreach (DataRow rezervaceRow in rezervaceTable.Rows)
            {
                DataColumn rezervaceColumn = rezervaceTable.Columns["idRezervace"];
                string idRezervace = rezervaceRow[rezervaceColumn].ToString();

                //Smaže rezervace
                databaze.SetCommandText("DELETE FROM rezervace WHERE idRezervace='" + idRezervace + "';");
                databaze.ExecuteReader();

                //Smaže rezervace kurzů
                databaze.SetCommandText("DELETE FROM rezervaceLyzarskyKurz WHERE idRezervace='" + idRezervace + "';");
                databaze.ExecuteReader();

                //Smaže rezervaci lyžařského vybavení
                databaze.SetCommandText("DELETE FROM rezervaceVybaveni WHERE idRezervace='" + idRezervace + "';");
                databaze.ExecuteReader();

                //Smaže provize rezervace
                databaze.SetCommandText("DELETE FROM rezervaceProvize WHERE idRezervace='" + idRezervace + "';");
                databaze.ExecuteReader();
            }
        }

        return true;
    }


    /// <summary>
    /// Načte seznam provizí pro partnera lyžařské školy.
    /// </summary>
    /// <param name="idZakaznika">Id partnera, kterému provize náleží.</param>
    /// <returns><c>ArrayList</c> - seznam provizí.</returns>
    public static ArrayList NacistSeznamProviziPartnera(string idPartnera)
    {
        ArrayList seznam = new ArrayList();
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("SELECT idRezervace, od, do, nazevPobocky, cenaKonecna, stavRezervace, provize, datumVyplaceni FROM provizePartnerView WHERE idPartnera='" + idPartnera + "' ORDER BY do;");
            SqlDataReader reader = databaze.ExecuteReader();
            while (reader.Read())
            {
                float vyseProvize = 0; DateTime datumVyplaceni;
                if (float.TryParse(reader["provize"].ToString(), out vyseProvize))
                    vyseProvize = float.Parse(reader["provize"].ToString());
                if (DateTime.TryParse(reader["datumVyplaceni"].ToString(), out datumVyplaceni))
                    datumVyplaceni = DateTime.Parse(reader["datumVyplaceni"].ToString());

                Provize provize = new Provize(vyseProvize, datumVyplaceni, "", new Partner(idPartnera), new Rezervace(int.Parse(reader["idRezervace"].ToString()), null, new Pobocka(0, reader["nazevPobocky"].ToString()), "", 0, null, float.Parse(reader["cenaKonecna"].ToString()), DateTime.Parse(reader["od"].ToString()), DateTime.Parse(reader["do"].ToString()), new RezervaceStav(reader["stavRezervace"].ToString()), ""));
                seznam.Add(provize);
            }
        }
        catch (Exception)
        {
        }
        return seznam;
    }


    /// <summary>
    /// Načte provize.
    /// </summary>
    /// <returns>Provize.</returns>
    public static DataSet NacistSeznamProvizi()
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT idRezervace, datumVyplaceni, poznamka, partnerskyKod, jmeno, prijmeni, cenaKonecna, provize FROM provizeView;", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte provizi.
    /// </summary>
    /// <param name="idRezervace">Id rezervace.</param>
    /// <returns>Provize.</returns>
    public static Provize NacistProvizi(int idRezervace)
    {
        Provize provize = new Provize(new Rezervace(idRezervace, null));
        if (provize.Nacist())
            return provize;
        return null;
    }

    /// <summary>
    /// Načte provizi.
    /// </summary>
    /// <param name="rezervace">Rezervace.</param>
    /// <returns>Provize.</returns>
    public static Provize NacistProvizi(Rezervace rezervace)
    {
        Provize provize = new Provize(rezervace);
        if (provize.Nacist())
            return provize;
        return null;
    }




    /// <summary>
    /// Načte rezervaci.
    /// </summary>
    /// <param name="idRezervace">Id rezervace, která se má načíst.</param>
    /// <returns>Načtená rezervace.</returns>
    public static Rezervace NacistRezervaci(int idRezervace)
    {
        Rezervace rezervace = new Rezervace(idRezervace, null);
        if (rezervace.NacistRezervaci())
            return rezervace;
        return null;
    }

    /// <summary>
    /// Smaže stav rezervace z databáze.
    /// </summary>
    /// <param name="idStavuRezervace">Id stavu rezrvace, který se má smazat.</param>
    /// <returns><c>True</c>, pokud smazání proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool SmazatStavRezervace(int idStavuRezervace)
    {
        RezervaceStav stav = new RezervaceStav(idStavuRezervace);
        return stav.SmazatStavRezervace();

    }

    /// <summary>
    /// Uloží stav rezervace.
    /// </summary>
    /// <param name="idStavuRezervace">Id stavu rezervace.</param>
    /// /// <param name="stavRezervace">Název stavu rezervace.</param>
    /// <param name="info">Informace o stavu rezervace.</param>
    /// <returns><c>True</c>, pokud uložení proběhlo v pořádku, jinak <c>false</c>.</returns>
    public static bool UlozitStavRezervace(int idStavuRezervace, string stavRezervace, string info)
    {
        RezervaceStav stav = new RezervaceStav(idStavuRezervace, stavRezervace, info);
        return stav.UlozitStavRezervace();
    }


}
