﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections;
using System.Data.SqlClient;

/// <summary>
/// Summary description for SpravceUzivatelu
/// </summary>
public static class SpravceUzivatelu
{
   
    /// <summary>
    /// Zjistí, zda zadaný partnerský kód existuje.
    /// </summary>
    /// <param name="partnerskyKod">Partnerský kód, který se má zkotrolovat</param>
    /// <returns><c>True</c>, pokud existuje, <c>false</c> pokud neexistuje</returns>
    public static bool ExistujePartnerskyKod(string partnerskyKod)
    {
        return Partner.ExistujePartnerskyKod(partnerskyKod);
    }

    /// <summary>
    /// Načte informace o zákazníkovi.
    /// </summary>
    /// <param name="idZakaznika">Id zákazníka, který se má načíst.</param>
    /// <returns>Zákazník.</returns>
    public static Zakaznik NacistZakaznika(string idZakaznika)
    {
        Zakaznik zakaznik = new Zakaznik(idZakaznika);
        if (zakaznik.Nacist())
            return zakaznik;
        return null;
    }

    /// <summary>
    /// Uloží informace o zákazníkovi do databáze.
    /// </summary>
    /// <param name="zakaznik">Zákazník, který se má uložit.</param>
    /// <returns><c>True</c> v případě, že uložení proběhlo úspěšně, jinak <c>False</c>.</returns>
    public static bool UlozitInformaceOZakaznikovi(Zakaznik zakaznik)
    {
        return zakaznik.Ulozit();
    }

    /// <summary>
    /// Načte informace o instruktorovi.
    /// </summary>
    /// <param name="idInstruktora">Id instruktora, který se má načíst.</param>
    /// <returns>Načtený instruktor.</returns>
    public static Instruktor NacistInstruktora(string idInstruktora)
    {
        Instruktor instruktor = new Instruktor(idInstruktora);
        if (instruktor.Nacist())
            return instruktor;
        return null;
    }

    /// <summary>
    /// Uloží informace o instruktorovi do databáze.
    /// </summary>
    /// <param name="instruktor">Instruktor</param>
    /// <returns>True, pokud je instruktor úspěšně uložen, jinak false.</returns>
    public static bool UlozitInformaceOInstruktorovi(Instruktor instruktor)
    {
        return instruktor.Ulozit();
    }

    /// <summary>
    /// Načte informace o partnerovi lyžařské školy.
    /// </summary>
    /// <param name="idZakaznika">Id partnera, který se má načíst.</param>
    /// <returns>Partner lyžařské školy.</returns>
    public static Partner NactiPartnera(string idPartnera)
    {
        Partner partner = new Partner(idPartnera);
        if (partner.Nacist())
            return partner;
        return null;
    }

    /// <summary>
    /// Uloží informace o partnerovi do databáze.
    /// </summary>
    /// <param name="partner">Partner lyžařské školy</param>
    /// <returns><c>True</c>, pokud je partner úspěšně uložen, jinak <c>false</c>.</returns>
    public static bool UlozitInformaceOPartnerovi(Partner partner)
    {
        return partner.Ulozit();
    }

    /// <summary>
    /// Načte id partnera podle partnerského kódu.
    /// </summary>
    /// <param name="partnerskyKod">Partnerský kód.</param>
    /// <returns>Id partnerského kódu, pokud neexistuje, tak <c>null</c>.</returns>
    public static string NacistIdPartneraPodlePartnerskehoKodu(string partnerskyKod)
    {
        return Partner.NacistIdPartneraPodlePartnerskehoKodu(partnerskyKod);
    }

    /// <summary>
    /// Načte instruktory
    /// </summary>
    /// <returns>Seznam instruktorů</returns>
    public static DataSet NacistInstruktory()
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT UserName, jmeno, prijmeni, Email, informace FROM instruktorView;", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte uživatele.
    /// </summary>
    /// <returns>Seznam uživatelů.</returns>
    public static DataSet NacistUzivatele(string role)
    {
        SqlDataAdapter adapter = new SqlDataAdapter("SELECT UserName, jmeno, prijmeni, telefon, UserId, RoleName FROM uzivateleView WHERE RoleName='" + role + "';", Databaze.GetConnection());
        DataSet ds = new DataSet();
        adapter.Fill(ds);
        return ds;
    }

    /// <summary>
    /// Načte uživatele.
    /// </summary>
    /// <param name="idUzivatele">Id uživatele.</param>
    /// <returns>Uživatel.</returns>
    public static Uzivatel NacistUzivateleSystemu(string idUzivatele)
    {
        Uzivatel uzivatel = new Uzivatel(idUzivatele);
        if (uzivatel.Nacist())
            return uzivatel;
        return null;
    }

    /// <summary>
    /// Načte informace o administratorovi.
    /// </summary>
    /// <param name="idInstruktora">Id administratora, který se má načíst.</param>
    /// <returns>Načtený administrator.</returns>
    public static Administrator NacistAdministratora(string idAdmin)
    {
        Administrator admin = new Administrator(idAdmin);
        if (admin.Nacist())
            return admin;
        return null;
    }

    /// <summary>
    /// Uloží informace o partnerovi do databáze.
    /// </summary>
    /// <param name="partner">Partner lyžařské školy</param>
    /// <returns><c>True</c>, pokud je partner úspěšně uložen, jinak <c>false</c>.</returns>
    public static bool UlozitInformaceOAdministratorovi(Administrator admin)
    {
        return admin.Ulozit();
    }

    /// <summary>
    /// Zjistí id uživatele.
    /// </summary>
    /// <param name="userName">User name uživatele.</param>
    /// <returns>Id uživatele.</returns>
    public static string ZjistitIdUzivatele(string userName)
    {
        return Uzivatel.ZjistitIdUzivatele(userName);
    }
}
