﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Data.SqlClient;

/// <summary>
/// Třída pro práci se zákazníkem.
/// </summary>
public class Zakaznik : Uzivatel
{
    private Adresa fakturacniAdresa;

    /// <summary>
    /// Zákazník.
    /// </summary>
    /// <param name="id">Id zákazníka.</param>
    public Zakaznik(string id)
        : base(id)
    {
        fakturacniAdresa = new Adresa();
    }

    /// <summary>
    /// Zákazník.
    /// </summary>
    /// <param name="id">Id zákazníka</param>
    /// <param name="nick">Nick.</param>
    /// <param name="jmeno">Jméno.</param>
    /// <param name="prijmeni">Příjmení.</param>
    /// <param name="email">Email.</param>
    public Zakaznik(string id, string nick, string jmeno, string prijmeni, string email)
        : base(id, nick, "", jmeno, prijmeni, email, "")
    {
        this.fakturacniAdresa = new Adresa();
    }

    /// <summary>
    /// Zákazník.
    /// </summary>
    /// <param name="id">Id zákazníka</param>
    /// <param name="nick">Nick.</param>
    /// <param name="jmeno">Jméno.</param>
    /// <param name="prijmeni">Příjmení.</param>
    /// <param name="email">Email.</param>
    /// <param name="fakturacniAdresa">Fakturační adresa zákazníka.</param>
    /// <param name="telefonniCislo">Telefonní číslo.</param>
    public Zakaznik(string id, string nick, string heslo, string jmeno, string prijmeni, string email, Adresa fakturacniAdresa, string telefonniCislo)
        : base(id, nick, heslo, jmeno, prijmeni, email, telefonniCislo)
    {
        this.fakturacniAdresa = fakturacniAdresa;
    }

    /// <summary>
    /// Vrátí nebo nastaví fakturační adresu.
    /// </summary>
    public Adresa FakturacniAdresa
    {
        get { return fakturacniAdresa; }
        set { this.fakturacniAdresa = value; }
    }

    /// <summary>
    /// Načte zákazníka z databáze.
    /// </summary>
    /// <returns><c>True</c> v případě, že načtení proběhlo úspěšně, jinak <c>False</c>.</returns>
    public bool Nacist()
    {
        if (base.Nacist())
        {
            try
            {
                Databaze databaze = new Databaze();
                databaze.SetCommandText("SELECT ulice, mesto, psc FROM zakaznik WHERE idUzivatele='" + this.Id + "';");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                {
                    this.fakturacniAdresa.Ulice = reader["ulice"].ToString();
                    this.fakturacniAdresa.Mesto = reader["mesto"].ToString();
                    this.fakturacniAdresa.Psc = reader["psc"].ToString();
                    return true;
                }
                
            }
            catch (Exception)
            {
                return false;
            }
        }
        return false;
    }

    /// <summary>
    /// Uloží zákazníka do databáze.
    /// </summary>
    /// <returns><c>True</c> v případě, že uložení proběhlo úspěšně, jinak <c>False</c>.</returns>
    public bool Ulozit()
    {
        try
        {
            if (base.Ulozit())
            {
                Databaze databaze = new Databaze();

                bool exist = false;
                databaze.SetCommandText("SELECT 'r' FROM zakaznik WHERE idUzivatele='" + this.Id + "'");
                SqlDataReader reader = databaze.ExecuteReader();
                while (reader.Read())
                    exist = true;

                if (exist)
                    databaze.SetCommandText("UPDATE zakaznik SET psc='" + this.fakturacniAdresa.Psc + "', mesto='" + this.fakturacniAdresa.Mesto + "', ulice='" + this.fakturacniAdresa.Ulice + "' WHERE idUzivatele='" + this.Id + "';");
                else
                    databaze.SetCommandText("INSERT INTO zakaznik (idUzivatele, ulice, mesto, psc) VALUES ('" + this.Id + "', '" + this.fakturacniAdresa.Ulice + "','" + this.fakturacniAdresa.Mesto + "','" + this.fakturacniAdresa.Psc + "');");
                databaze.ExecuteReader();
                return true;
            }
            else
                return false;
        }
        catch (Exception)
        {
            return false;
        }
    }

    /// <summary>
    /// Smaže zákazníka z databáze.
    /// </summary>
    /// <returns><c>True</c> v případě, že smazání proběhlo úspěšně, jinak <c>False</c>.</returns>
    public bool Smazat()
    {
        if (!SpravceRezervaci.SmazatRezervaceUzivatele(this.Id))
            return false;
        try
        {
            Databaze databaze = new Databaze();
            databaze.SetCommandText("DELETE FROM zakaznik WHERE idUzivatele='" + this.Id + "';");
            databaze.ExecuteReader();

            return true;
        }
        catch (Exception)
        {
            return false;
        }
    }
}

