﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

public partial class MeRezervace : System.Web.UI.Page
{

    protected void Page_Load(object sender, EventArgs e)
    {

        if (!Page.User.Identity.IsAuthenticated)
            Response.Redirect("Default.aspx");


        //Vypíše seznamy rezervací, nebo celé rezervace
        if (Request.QueryString["detail"] == null)
        {
            prehledRezervaciPanel.Visible = true;

            ArrayList seznamRezervaci = new ArrayList();
            if (Page.User.IsInRole("zakaznik") || Page.User.IsInRole("partner"))
            {
                //seznamRezervaci = SpravceRezervaci.NactiSeznamRezervaciZakaznika(Profile.userId);
                informaceLiteral.Text = "Zde máte přehled všech vašich rezervací.";
            }
            else if (Page.User.IsInRole("instruktor"))
            {
                //seznamRezervaci = SpravceRezervaci.NactiSeznamRezervaciInstruktora(Profile.userId);
                informaceLiteral.Text = "Zde máte přehled rezervací, které jste vyučoval(a).";
                meRezervaceObjectDataSource.SelectMethod = "NactiSeznamRezervaciInstruktora";
            }
        }
        else
        {
            rezervacePanel.Visible = true;

            RezervaceLyzarskehoKurzu rezervace = null;
            RezervaceLyzarskehoVybaveni lyzarskeVybaveni = null;

            if (Page.User.IsInRole("zakaznik") || Page.User.IsInRole("partner"))
            {
                rezervace = SpravceRezervaci.NacistRezervaciLyzarskehoKurzuZakaznika(int.Parse(Request.QueryString["detail"]), Profile.userId);
                lyzarskeVybaveni = SpravceRezervaci.NacistRezervaciLyzarskehoVybaveniZakaznika(int.Parse(Request.QueryString["detail"]), Profile.userId);
            }
            else if (Page.User.IsInRole("instruktor"))
            {
                rezervace = SpravceRezervaci.NacistRezervaciLyzarskehoKurzuInstruktora(int.Parse(Request.QueryString["detail"]), Profile.userId);
            }

            if (rezervace != null)
            {
                VypisUdajeORezervaci(rezervace);
                VypisUdajeORezervaciLyzarskehoKurzu(rezervace);

                if (lyzarskeVybaveni != null)
                    VypisUdajeORezervaciLyzarskehoVybaveni(lyzarskeVybaveni);

            }
            else
            {
                if (lyzarskeVybaveni != null)
                {
                    VypisUdajeORezervaci(lyzarskeVybaveni);
                    VypisUdajeORezervaciLyzarskehoVybaveni(lyzarskeVybaveni);
                }
            }
        }

    }

    /// <summary>
    /// Vypíše údaje o rezervaci lyžařského kurzu
    /// </summary>
    /// <param name="rezervace">Rezervace lyžařského kurzu.</param>
    protected void VypisUdajeORezervaciLyzarskehoKurzu(RezervaceLyzarskehoKurzu rezervace)
    {
        lyzarskyKurzPanel.Visible = true;

        if (rezervace.KonecRezervace > DateTime.Now)
            hodnoceniLiteral.Text = "Hodnocení kurzu bude možné provést po skončení kurzu.";
        else
            if (rezervace.ZpetneHodnoceni == "")
            {
                if (Page.User.IsInRole("zakaznik") || Page.User.IsInRole("partner"))
                {
                    hodnoceniLiteral.Text = "Ohodnoťte prosím průběh tohoto kurzu.";
                    hodnoceniPanel.Visible = true;
                }
            }
            else
                hodnoceniLiteral.Text = rezervace.ZpetneHodnoceni;


        slevaPocetOsobLiteral.Text = rezervace.Slevy.SlevaPocetOsob.ToString();
        pobockaLiteral.Text = rezervace.Pobocka.NazevPobocky;
        partnerskyKodLiteral.Text = rezervace.PartnerskyKod;
        slevaPartnerskyKodLiteral.Text = rezervace.Slevy.PouzitiPartnerskehoKodu.ToString();
        poznamkaLiteral.Text = rezervace.Poznamka;

        kurzLiteral.Text = rezervace.Kurz;
        if (rezervace.PreferovanyInstruktor != null)
            preferovanyInstruktorLiteral.Text = rezervace.PreferovanyInstruktor.Jmeno + " " + rezervace.PreferovanyInstruktor.Prijmeni;
        skutecnyInstruktorLiteral.Text = rezervace.SkutecnyInstruktor.Jmeno + " " + rezervace.SkutecnyInstruktor.Prijmeni;
        pocetOsobLiteral.Text = rezervace.PocetOsob.ToString();
    }

    /// <summary>
    /// Vypíše údaje o rezervaci lyžařského vybavení.
    /// </summary>
    /// <param name="lyzarskeVybaveni">Rezervace lyžařského vybavení.</param>
    protected void VypisUdajeORezervaciLyzarskehoVybaveni(RezervaceLyzarskehoVybaveni lyzarskeVybaveni)
    {
        int i = 1;
        lyzarskeVybaveniPanel.Visible = true;
        foreach (RezervaceLyzarskehoVybaveniPolozky polozka in lyzarskeVybaveni.SeznamPolozek)
        {
            TableRow tr = new TableRow();

            TableCell td = new TableCell();
            td.Text = i + ". " + polozka.Typ;
            tr.Cells.Add(td);

            td = new TableCell();
            td.Text = polozka.Vyska + " cm, " + polozka.Vaha + " kg, " + polozka.VelikostBoty;
            tr.Cells.Add(td);

            td = new TableCell();
            td.HorizontalAlign = HorizontalAlign.Right;
            if (polozka.Cena == 0)
                td.Text = "v ceně balíčku";
            else
                td.Text = polozka.Cena.ToString("f2") + "&nbsp;Kč";
            tr.Cells.Add(td);

            lyzarskeVybaveniTable.Rows.Add(tr);
            i++;
        }
    }

    /// <summary>
    /// Vypíše údaje o rezervaci.
    /// </summary>
    /// <param name="rezervace">Rezervace.</param>
    protected void VypisUdajeORezervaci(Rezervace rezervace)
    {
        cisloRezervaceLiteral.Text = " - ref. č. " + rezervace.ReferencniCislo.ToString();

        stavLiteral.Text = rezervace.StavRezervace.NazevStavuRezervace;
        slevaOnlineLiteral.Text = rezervace.Slevy.OnLineRezervace.ToString();
        terminRezervaceDoLiteral.Text = rezervace.ZacatekRezervace.ToLongDateString() + " - " + rezervace.KonecRezervace.ToLongDateString();
        slevaTerminLiteral.Text = rezervace.Slevy.VcasnaRezervace.ToString();
        slevaPocetOsobLiteral.Text = rezervace.Slevy.SlevaPocetOsob.ToString();
        pobockaLiteral.Text = rezervace.Pobocka.NazevPobocky;
        partnerskyKodLiteral.Text = rezervace.PartnerskyKod;
        slevaPartnerskyKodLiteral.Text = rezervace.Slevy.PouzitiPartnerskehoKodu.ToString();
        poznamkaLiteral.Text = rezervace.Poznamka;

        cenaPredSlevouLiteral.Text = rezervace.CenaPredSlevou.ToString("f2");
        slevaCelkemLiteral.Text = rezervace.Slevy.MaximalniSleva.ToString();
        cenaKonecnaLiteral.Text = rezervace.CenaKonecna.ToString("f2");
    }


    /// <summary>
    /// Uloží hodnocení lyžařského kurzu.
    /// </summary>
    /// <param name="sender"><c>Object</c>.</param>
    /// <param name="e"><c>EventArgs</c>.</param>
    protected void hodnoceniButton_Click(object sender, EventArgs e)
    {
        int idRezervace = 0;
        if (int.TryParse(Request.QueryString["detail"], out idRezervace))
            if (SpravceRezervaci.UlozitHodnoceniKurzu(int.Parse(Request.QueryString["detail"]), new Zakaznik(Profile.userId), hodnoceniTextBox.Text))
            {
                hodnoceniLiteral.Text = hodnoceniTextBox.Text;
                hodnoceniPanel.Visible = false;
            }
    }

}
