﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

public partial class admin_CenikyLyzarskeKurzy : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Request.QueryString["action"] == "new")
        {
            seznamPanel.Visible = false;
            detailPanel.Visible = true;
            h2DetailLiteral.Text = "Nový lyžařský kurz";
            if (!Page.IsPostBack)
                VytvorDynamickyRadek(0, "");
        }
        else if (Request.QueryString["action"] == "update")
        {
            seznamPanel.Visible = false;
            detailPanel.Visible = true;
            h2DetailLiteral.Text = "Upravit lyžařský kurz";

            if (!Page.IsPostBack)
            {
                VypisLyzarskyKurz(int.Parse(Request.QueryString["id"]));
            }
        }
        else if (Request.QueryString["action"] == "delete")
        {
            seznamPanel.Visible = false;
            detailPanel.Visible = true;
            polozkyPanel.Enabled = false;
            h2DetailLiteral.Text = "Opravdu se má lyžařský kurz smazat?";
            if (!Page.IsPostBack)
            {
                VypisLyzarskyKurz(int.Parse(Request.QueryString["id"]));
            }
        }
        else
        {
            seznamPanel.Visible = true;
            detailPanel.Visible = false;
        }

        //Vypíše při PostBacku dynamické řádky
        if (Page.IsPostBack)
        {
            for (int i = 0; i <= int.Parse(pocetRozsahuTextBox.Text); i++)
            {
                VytvorDynamickyRadek(i, "");
            }
        }

    }


    /// <summary>
    /// Vytvoří dynamický řádek cena pro počet dní.
    /// </summary>
    /// <param name="cisloDne">Pořadové číslo dne.</param>
    /// <param name="cena">Cena.</param>
    protected void VytvorDynamickyRadek(int cisloDne, string cena)
    {
        if (cisloDne == 0)
            dynPanel.Controls.Add(new LiteralControl("<tr><td>Každý další den</td><td>"));
        else
            dynPanel.Controls.Add(new LiteralControl("<tr><td>" + cisloDne.ToString() + " " + FunkceRezervacnihoSystemu.GetStringPocetDni(cisloDne) + "</td><td>"));

        //Cena
        TextBox cenaTextBox = new TextBox();
        cenaTextBox.ID = "cena" + cisloDne.ToString() + "TextBox";
        if (cena != "")
            cenaTextBox.Text = cena;
        dynPanel.Controls.Add(cenaTextBox);
        dynPanel.Controls.Add(new LiteralControl(" Kč"));

        //Validator ceny
        RequiredFieldValidator cenaRequireFild = new RequiredFieldValidator();
        cenaRequireFild.ControlToValidate = "cena" + cisloDne.ToString() + "TextBox";
        cenaRequireFild.Display = ValidatorDisplay.Dynamic;
        cenaRequireFild.ErrorMessage = "<br />Musíte zadat cenu.";
        cenaRequireFild.ValidationGroup = "detail";
        dynPanel.Controls.Add(cenaRequireFild);

        dynPanel.Controls.Add(new LiteralControl("</td></tr>"));
    }

    /// <summary>
    /// Vypíše lyžařský kurz.
    /// </summary>
    /// <param name="idKurzu">Id kurzu.</param>    
    protected void VypisLyzarskyKurz(int idKurzu)
    {
        CenikKurzu kurz = SpravceCeniku.NacistCenikKurzu(idKurzu, true);
        idLiteral.Text = kurz.IdKurzu.ToString();
        nazevTextBox.Text = kurz.NazevKurzu;
        infoTextBox.Text = kurz.Info;

        pocetRozsahuTextBox.Text = (kurz.PolozkyCeniku.Count - 1).ToString();

        for (int cisloDne = 0; cisloDne < kurz.PolozkyCeniku.Count; cisloDne++)
        {
            string idControl = "cena" + cisloDne.ToString() + "TextBox";
            if (dynPanel.FindControl(idControl) == null)
            {
                PolozkaCeniku polozka = (PolozkaCeniku)kurz.PolozkyCeniku[cisloDne];
                VytvorDynamickyRadek(cisloDne, polozka.Cena.ToString("f2"));
            }
        }
    }

    /// <summary>
    /// Smazání balíčku.
    /// </summary>
    protected void potvrdButton_Click(object sender, EventArgs e)
    {

        if (Request.QueryString["action"] == "delete")
        {
            if (!SpravceCeniku.SmazatCenikKurzu(int.Parse(idLiteral.Text)))
            {
                errorLiteral.Text = "Chyba při mazání kurzu.";
                return;
            }
        }
        else
        {
            ArrayList polozkyCeniku = new ArrayList();
            for (int cisloDne = 0; cisloDne <= int.Parse(pocetRozsahuTextBox.Text); cisloDne++)
            {
                string cenaControl = "cena" + cisloDne.ToString() + "TextBox";
                PolozkaCeniku polozka = new PolozkaCeniku(float.Parse(((TextBox)dynPanel.FindControl(cenaControl)).Text), cisloDne);
                polozkyCeniku.Add(polozka);
            }
            if (!SpravceCeniku.UlozitCenikLyzarskehoKurzu(int.Parse(idLiteral.Text), nazevTextBox.Text, infoTextBox.Text, polozkyCeniku))
            {
                errorLiteral.Text = "Chyba při ukládání.";
                return;
            }
        }

        Response.Redirect("CenikyLyzarskeKurzy.aspx");
    }


    /// <summary>
    /// Vrátí se zpět na přehled lyžařských kurzů.
    /// </summary>
    protected void zpetButton_Click(object sender, EventArgs e)
    {
        Response.Redirect("CenikyLyzarskeKurzy.aspx");
    }
}
