﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

public partial class admin_UzivateleRole : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Request.QueryString["UserId"] == null)
            PresmerujNaStrankuUzivatelu();
        Uzivatel uzivatel = SpravceUzivatelu.NacistUzivateleSystemu(Request.QueryString["UserId"]);
        if (uzivatel == null)
            PresmerujNaStrankuUzivatelu();
        if (!Page.IsPostBack)
            VypisUzivatel(uzivatel);

    }

    /// <summary>
    /// Přesměruje na stránku uživatelů.
    /// </summary>
    protected void PresmerujNaStrankuUzivatelu()
    {
        Response.Redirect("Uzivatele.aspx");
    }

    /// <summary>
    /// Vypíše informace o uživateli.
    /// </summary>
    /// <param name="uzivatel">Uživatel.</param>
    protected void VypisUzivatel(Uzivatel uzivatel)
    {
        pridelRoleDropDownList.Items.Clear();
        odeberRoleDropDownList.Items.Clear();
        foreach (string role in Roles.GetAllRoles())
        {
            if (!Roles.IsUserInRole(uzivatel.Nick, role))
                pridelRoleDropDownList.Items.Add(new ListItem(role));
            else
                odeberRoleDropDownList.Items.Add(new ListItem(role));
        }

        if (odeberRoleDropDownList.Items.Count == 1)
            odeberRoliButton.Enabled = false;
        else
            odeberRoliButton.Enabled = true;

        userNameViewLiteral.Text = uzivatel.Nick;
        emailLiteral.Text = uzivatel.Email;
        jmenoLiteral.Text = uzivatel.Jmeno;
        prijmeniLiteral.Text = uzivatel.Prijmeni;
        telefonLiteral.Text = uzivatel.TelefonniCislo;
        roleLiteral.Text = "";
        foreach (string role in Roles.GetRolesForUser(uzivatel.Nick))
            roleLiteral.Text += role + ", ";
        roleLiteral.Text = roleLiteral.Text.Substring(0, roleLiteral.Text.Length - 2);
    }

    protected void pridelRoliButton_Click(object sender, EventArgs e)
    {
        Uzivatel uzivatel = SpravceUzivatelu.NacistUzivateleSystemu(Request.QueryString["UserId"]);
        switch (pridelRoleDropDownList.SelectedItem.Value)
        {
            case "admin":
                Administrator admin = SpravceUzivatelu.NacistAdministratora(uzivatel.Id);
                if (admin == null)
                {
                    admin = new Administrator(uzivatel.Id, uzivatel.Nick, uzivatel.Jmeno, uzivatel.Prijmeni, uzivatel.Email, uzivatel.TelefonniCislo);
                    admin.Ulozit();
                }
                Roles.AddUserToRole(admin.Nick, "admin");
                break;
            case "zakaznik":
                Zakaznik zakaznik = SpravceUzivatelu.NacistZakaznika(uzivatel.Id);
                if (zakaznik == null)
                {
                    zakaznik = new Zakaznik(uzivatel.Id, uzivatel.Nick, "", uzivatel.Jmeno, uzivatel.Prijmeni, uzivatel.Email, new Adresa(), uzivatel.TelefonniCislo);
                    zakaznik.Ulozit();
                }
                Roles.AddUserToRole(zakaznik.Nick, "zakaznik");
                break;
            case "instruktor":
                Instruktor instruktor = SpravceUzivatelu.NacistInstruktora(uzivatel.Id);
                if (instruktor == null)
                {
                    instruktor = new Instruktor(uzivatel.Id, uzivatel.Nick, uzivatel.Email, uzivatel.Jmeno, uzivatel.Prijmeni, uzivatel.TelefonniCislo, "");
                    instruktor.Ulozit();
                }
                Roles.AddUserToRole(instruktor.Nick, "instruktor");
                break;
            case "partner":
                Partner partner = SpravceUzivatelu.NactiPartnera(uzivatel.Id);
                if (partner == null)
                {
                    partner = new Partner(uzivatel.Id, uzivatel.Nick, uzivatel.Jmeno, uzivatel.Prijmeni, uzivatel.Email, "", uzivatel.TelefonniCislo, "");
                    partner.Ulozit();
                }
                Roles.AddUserToRole(partner.Nick, "partner");
                break;
            default:
                break;
        }
        VypisUzivatel(uzivatel);
    }


    protected void odeberRoliButton_Click(object sender, EventArgs e)
    {
        Uzivatel uzivatel = SpravceUzivatelu.NacistUzivateleSystemu(Request.QueryString["UserId"]);
        switch (odeberRoleDropDownList.SelectedItem.Value)
        {
            case "admin":
                Administrator admin = new Administrator(uzivatel.Id, uzivatel.Nick, uzivatel.Jmeno, uzivatel.Prijmeni, uzivatel.Email, uzivatel.TelefonniCislo);
                admin.Smazat();
                Roles.RemoveUserFromRole(admin.Nick, "admin");
                break;
            case "zakaznik":
                Zakaznik zakaznik = new Zakaznik(uzivatel.Id);
                zakaznik.Smazat();
                Roles.RemoveUserFromRole(uzivatel.Nick, "zakaznik");
                break;
            case "instruktor":
                Instruktor instruktor = new Instruktor(uzivatel.Id);
                instruktor.Smazat();
                Roles.RemoveUserFromRole(uzivatel.Nick, "instruktor");
                break;
            case "partner":
                Partner partner = new Partner(uzivatel.Id);
                partner.Smazat();
                Roles.RemoveUserFromRole(uzivatel.Nick, "partner");
                break;
            default:
                break;
        }
        VypisUzivatel(uzivatel);
    }
}
